<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => '.',
    'None' => 'Keines',
    'Edit' => 'Bearbeiten',
    'Remove' => 'Entfernen',
    'Yes' => 'Ja',
    'No' => 'Nein',
    'cancel' => 'Abbrechen',
    'or' => 'oder',
    'Yellow' => 'Gelb',
    'Blue' => 'Blau',
    'Green' => 'Grün',
    'Purple' => 'Violett',
    'Red' => 'Rot',
    'Orange' => 'Orange',
    'Grey' => 'Grau',
    'Brown' => 'Braun',
    'Deep Orange' => 'Dunkelorange',
    'Dark Grey' => 'Dunkelgrau',
    'Pink' => 'Pink',
    'Teal' => 'Türkis',
    'Cyan' => 'Cyan',
    'Lime' => 'Limette',
    'Light Green' => 'Hellgrün',
    'Amber' => 'Bernstein',
    'Save' => 'Speichern',
    'Login' => 'Anmelden',
    'Official website:' => 'Offizielle Webseite:',
    'Unassigned' => 'Nicht zugeordnet',
    'View this task' => 'Aufgabe ansehen',
    'Remove user' => 'Benutzer löschen',
    'Do you really want to remove this user: "%s"?' => 'Soll dieser Benutzer wirklich gelöscht werden: "%s"?',
    'All users' => 'Alle Benutzer',
    'Username' => 'Benutzername',
    'Password' => 'Passwort',
    'Administrator' => 'Administrator',
    'Sign in' => 'Anmelden',
    'Users' => 'Benutzer',
    'Forbidden' => 'Verboten',
    'Access Forbidden' => 'Zugriff verboten',
    'Edit user' => 'Benutzer bearbeiten',
    'Logout' => 'Abmelden',
    'Bad username or password' => 'Falscher Benutzername oder Passwort',
    'Edit project' => 'Projekt bearbeiten',
    'Name' => 'Name',
    'Projects' => 'Projekte',
    'No project' => 'Keine Projekte',
    'Project' => 'Projekt',
    'Status' => 'Status',
    'Tasks' => 'Aufgaben',
    'Board' => 'Pinnwand',
    'Actions' => 'Aktionen',
    'Inactive' => 'Inaktiv',
    'Active' => 'Aktiv',
    'Unable to update this board.' => 'Ändern dieser Pinnwand nicht möglich.',
    'Disable' => 'Deaktivieren',
    'Enable' => 'Aktivieren',
    'New project' => 'Neues Projekt',
    'Do you really want to remove this project: "%s"?' => 'Soll dieses Projekt wirklich gelöscht werden: "%s"?',
    'Remove project' => 'Projekt löschen',
    'Edit the board for "%s"' => 'Pinnwand für "%s" bearbeiten',
    'Add a new column' => 'Neue Spalte hinzufügen',
    'Title' => 'Titel',
    'Assigned to %s' => 'Zuständig: %s',
    'Remove a column' => 'Spalte löschen',
    'Unable to remove this column.' => 'Löschen dieser Spalte nicht möglich.',
    'Do you really want to remove this column: "%s"?' => 'Soll diese Spalte wirklich gelöscht werden: "%s"?',
    'Settings' => 'Einstellungen',
    'Application settings' => 'Anwendungskonfiguration',
    'Language' => 'Sprache',
    'Webhook token:' => 'Webhook Token:',
    'API token:' => 'API Token:',
    'Database size:' => 'Datenbankgröße:',
    'Download the database' => 'Datenbank herunterladen',
    'Optimize the database' => 'Datenbank optimieren',
    '(VACUUM command)' => '(VACUUM Befehl)',
    '(Gzip compressed Sqlite file)' => '(Gzip-komprimierte SQLite-Datei)',
    'Close a task' => 'Aufgabe abschließen',
    'Column' => 'Spalte',
    'Color' => 'Farbe',
    'Assignee' => 'Zuständiger',
    'Create another task' => 'Weitere Aufgabe erstellen',
    'New task' => 'Neue Aufgabe',
    'Open a task' => 'Öffne eine Aufgabe',
    'Do you really want to open this task: "%s"?' => 'Soll diese Aufgabe wirklich wieder geöffnet werden: "%s"?',
    'Back to the board' => 'Zurück zur Pinnwand',
    'There is nobody assigned' => 'Die Aufgabe wurde niemandem zugewiesen',
    'Column on the board:' => 'Spalte:',
    'Close this task' => 'Aufgabe schließen',
    'Open this task' => 'Aufgabe wieder öffnen',
    'There is no description.' => 'Keine Beschreibung vorhanden.',
    'Add a new task' => 'Neue Aufgabe hinzufügen',
    'The username is required' => 'Der Benutzername wird benötigt',
    'The maximum length is %d characters' => 'Die maximale Länge beträgt %d Zeichen',
    'The minimum length is %d characters' => 'Die minimale Länge beträgt %d Zeichen',
    'The password is required' => 'Das Passwort wird benötigt',
    'This value must be an integer' => 'Dieser Wert muss eine ganze Zahl sein',
    'The username must be unique' => 'Der Benutzername muss eindeutig sein',
    'The user id is required' => 'Die Benutzer-ID ist anzugeben',
    'Passwords don\'t match' => 'Passwörter nicht gleich',
    'The confirmation is required' => 'Die Bestätigung ist erforderlich',
    'The project is required' => 'Das Projekt ist anzugeben',
    'The id is required' => 'Die ID ist anzugeben',
    'The project id is required' => 'Die Projekt-ID ist anzugeben',
    'The project name is required' => 'Der Projektname ist anzugeben',
    'The title is required' => 'Der Titel ist anzugeben',
    'Settings saved successfully.' => 'Einstellungen erfolgreich gespeichert.',
    'Unable to save your settings.' => 'Speichern der Einstellungen nicht möglich.',
    'Database optimization done.' => 'Optimieren der Datenbank abgeschlossen.',
    'Your project has been created successfully.' => 'Das Projekt wurde erfolgreich erstellt.',
    'Unable to create your project.' => 'Erstellen des Projekts nicht möglich.',
    'Project updated successfully.' => 'Projekt erfolgreich geändert.',
    'Unable to update this project.' => 'Änderung des Projekts nicht möglich.',
    'Unable to remove this project.' => 'Löschen des Projekts nicht möglich.',
    'Project removed successfully.' => 'Projekt erfolgreich gelöscht.',
    'Project activated successfully.' => 'Projekt erfolgreich aktiviert.',
    'Unable to activate this project.' => 'Aktivieren des Projekts nicht möglich.',
    'Project disabled successfully.' => 'Projekt erfolgreich deaktiviert.',
    'Unable to disable this project.' => 'Deaktivieren des Projekts nicht möglich.',
    'Unable to open this task.' => 'Wiedereröffnung der Aufgabe nicht möglich.',
    'Task opened successfully.' => 'Aufgabe erfolgreich wieder geöffnet.',
    'Unable to close this task.' => 'Abschließen der Aufgabe nicht möglich.',
    'Task closed successfully.' => 'Aufgabe erfolgreich geschlossen.',
    'Unable to update your task.' => 'Aktualisieren der Aufgabe nicht möglich.',
    'Task updated successfully.' => 'Aufgabe erfolgreich aktualisiert.',
    'Unable to create your task.' => 'Erstellen der Aufgabe nicht möglich.',
    'Task created successfully.' => 'Aufgabe erfolgreich erstellt.',
    'User created successfully.' => 'Benutzer erfolgreich erstellt.',
    'Unable to create your user.' => 'Erstellen des Benutzers nicht möglich.',
    'User updated successfully.' => 'Benutzer erfolgreich geändert.',
    'User removed successfully.' => 'Benutzer erfolgreich gelöscht.',
    'Unable to remove this user.' => 'Löschen des Benutzers nicht möglich.',
    'Board updated successfully.' => 'Pinnwand erfolgreich geändert.',
    'Ready' => 'Bereit',
    'Backlog' => 'Ideen',
    'Work in progress' => 'In Arbeit',
    'Done' => 'Erledigt',
    'Application version:' => 'Version:',
    'Id' => 'ID',
    'Public link' => 'Öffentlicher Link',
    'Timezone' => 'Zeitzone',
    'Sorry, I didn\'t find this information in my database!' => 'Diese Information wurde in der Datenbank nicht gefunden!',
    'Page not found' => 'Seite nicht gefunden',
    'Complexity' => 'Komplexität',
    'Task limit' => 'Maximale Anzahl von Aufgaben',
    'Task count' => 'Aufgabenanzahl',
    'User' => 'Benutzer',
    'Comments' => 'Kommentare',
    'Comment is required' => 'Ein Kommentar wird benötigt',
    'Comment added successfully.' => 'Kommentar erfolgreich hinzugefügt.',
    'Unable to create your comment.' => 'Hinzufügen eines Kommentars nicht möglich.',
    'Due Date' => 'Fällig am',
    'Invalid date' => 'Ungültiges Datum',
    'Automatic actions' => 'Automatische Aktionen',
    'Your automatic action has been created successfully.' => 'Die automatische Aktion wurde erfolgreich erstellt.',
    'Unable to create your automatic action.' => 'Erstellen der automatischen Aktion nicht möglich.',
    'Remove an action' => 'Aktion löschen',
    'Unable to remove this action.' => 'Löschen der Aktion nicht möglich.',
    'Action removed successfully.' => 'Aktion erfolgreich gelöscht.',
    'Automatic actions for the project "%s"' => 'Automatische Aktionen für das Projekt "%s"',
    'Add an action' => 'Aktion hinzufügen',
    'Event name' => 'Ereignisname',
    'Action' => 'Aktion',
    'Event' => 'Ereignis',
    'When the selected event occurs execute the corresponding action.' => 'Wenn das gewählte Ereignis eintritt, führe die zugehörige Aktion aus.',
    'Next step' => 'Weiter',
    'Define action parameters' => 'Aktionsparameter definieren',
    'Do you really want to remove this action: "%s"?' => 'Soll diese Aktion wirklich gelöscht werden: "%s"?',
    'Remove an automatic action' => 'Löschen einer automatischen Aktion',
    'Assign the task to a specific user' => 'Aufgabe einem Benutzer zuordnen',
    'Assign the task to the person who does the action' => 'Aufgabe dem Benutzer zuordnen, der die Aktion ausgeführt hat',
    'Duplicate the task to another project' => 'Aufgabe in ein anderes Projekt kopieren',
    'Move a task to another column' => 'Aufgabe in andere Spalte verschieben',
    'Task modification' => 'Aufgabe ändern',
    'Task creation' => 'Aufgabe erstellen',
    'Closing a task' => 'Aufgabe abschließen',
    'Assign a color to a specific user' => 'Einem Benutzer eine Farbe zuordnen',
    'Position' => 'Position',
    'Duplicate to project' => 'In ein anderes Projekt duplizieren',
    'Duplicate' => 'Duplizieren',
    'Link' => 'Link',
    'Comment updated successfully.' => 'Kommentar erfolgreich aktualisiert.',
    'Unable to update your comment.' => 'Aktualisierung des Kommentars nicht möglich.',
    'Remove a comment' => 'Kommentar löschen',
    'Comment removed successfully.' => 'Kommentar erfolgreich gelöscht.',
    'Unable to remove this comment.' => 'Löschen des Kommentars nicht möglich.',
    'Do you really want to remove this comment?' => 'Soll dieser Kommentar wirklich gelöscht werden?',
    'Current password for the user "%s"' => 'Aktuelles Passwort des Benutzers "%s"',
    'The current password is required' => 'Das aktuelle Passwort wird benötigt',
    'Wrong password' => 'Falsches Passwort',
    'Unknown' => 'Unbekannt',
    'Last logins' => 'Letzte Anmeldungen',
    'Login date' => 'Anmeldedatum',
    'Authentication method' => 'Authentisierungsmethode',
    'IP address' => 'IP-Adresse',
    'User agent' => 'User-Agent',
    'Persistent connections' => 'Bestehende Verbindungen',
    'No session.' => 'Keine Sitzung.',
    'Expiration date' => 'Ablaufdatum',
    'Remember Me' => 'Angemeldet bleiben',
    'Creation date' => 'Erstellungsdatum',
    'Everybody' => 'Alle',
    'Open' => 'Offen',
    'Closed' => 'Abgeschlossen',
    'Search' => 'Suchen',
    'Nothing found.' => 'Nichts gefunden.',
    'Due date' => 'Fälligkeitsdatum',
    'Description' => 'Beschreibung',
    '%d comments' => '%d Kommentare',
    '%d comment' => '%d Kommentar',
    'Email address invalid' => 'Ungültige E-Mail-Adresse',
    'Your external account is not linked anymore to your profile.' => 'Ihr externer Account ist nicht mehr mit Ihrem Profil verbunden.',
    'Unable to unlink your external account.' => 'Externer Account konnte nicht getrennt werden.',
    'External authentication failed' => 'Externe Authentifizierung fehlgeschlagen',
    'Your external account is linked to your profile successfully.' => 'Ihr externer Account wurde erfolgreich mit Ihrem Profil verbunden',
    'Email' => 'E-Mail',
    'Task removed successfully.' => 'Aufgabe erfolgreich gelöscht.',
    'Unable to remove this task.' => 'Löschen der Aufgabe nicht möglich.',
    'Remove a task' => 'Aufgabe löschen',
    'Do you really want to remove this task: "%s"?' => 'Soll diese Aufgabe wirklich gelöscht werden: "%s"?',
    'Assign automatically a color based on a category' => 'Automatisch eine Farbe anhand der Kategorie zuweisen',
    'Assign automatically a category based on a color' => 'Automatisch eine Kategorie anhand der Farbe zuweisen',
    'Task creation or modification' => 'Aufgabe erstellen oder ändern',
    'Category' => 'Kategorie',
    'Category:' => 'Kategorie:',
    'Categories' => 'Kategorien',
    'Your category has been created successfully.' => 'Kategorie erfolgreich erstellt.',
    'This category has been updated successfully.' => 'Kategorie erfolgreich aktualisiert.',
    'Unable to update this category.' => 'Änderung der Kategorie nicht möglich.',
    'Remove a category' => 'Kategorie löschen',
    'Category removed successfully.' => 'Kategorie erfolgreich gelöscht.',
    'Unable to remove this category.' => 'Löschen der Kategorie nicht möglich.',
    'Category modification for the project "%s"' => 'Kategorie für das Projekt "%s" bearbeiten',
    'Category Name' => 'Kategoriename',
    'Add a new category' => 'Neue Kategorie',
    'Do you really want to remove this category: "%s"?' => 'Soll diese Kategorie wirklich gelöscht werden: "%s"?',
    'All categories' => 'Alle Kategorien',
    'No category' => 'Keine Kategorie',
    'The name is required' => 'Der Name ist erforderlich',
    'Remove a file' => 'Datei löschen',
    'Unable to remove this file.' => 'Löschen der Datei nicht möglich.',
    'File removed successfully.' => 'Datei erfolgreich gelöscht.',
    'Attach a document' => 'Dokument anhängen',
    'Do you really want to remove this file: "%s"?' => 'Soll diese Datei wirklich gelöscht werden: "%s"?',
    'Attachments' => 'Anhänge',
    'Edit the task' => 'Aufgabe bearbeiten',
    'Add a comment' => 'Kommentar hinzufügen',
    'Edit a comment' => 'Kommentar bearbeiten',
    'Summary' => 'Zusammenfassung',
    'Time tracking' => 'Zeiterfassung',
    'Estimate:' => 'Geschätzt:',
    'Spent:' => 'Aufgewendet:',
    'Do you really want to remove this sub-task?' => 'Soll diese Teilaufgabe wirklich gelöscht werden?',
    'Remaining:' => 'Verbleibend:',
    'hours' => 'Stunden',
    'estimated' => 'geschätzt',
    'Sub-Tasks' => 'Teilaufgaben',
    'Add a sub-task' => 'Teilaufgabe anlegen',
    'Original estimate' => 'Geschätzter Aufwand',
    'Create another sub-task' => 'Weitere Teilaufgabe anlegen',
    'Time spent' => 'Aufgewendete Zeit',
    'Edit a sub-task' => 'Teilaufgabe bearbeiten',
    'Remove a sub-task' => 'Teilaufgabe löschen',
    'The time must be a numeric value' => 'Zeit nur als nummerische Angabe',
    'Todo' => 'Nicht gestartet',
    'In progress' => 'In Bearbeitung',
    'Sub-task removed successfully.' => 'Teilaufgabe erfolgreich gelöscht.',
    'Unable to remove this sub-task.' => 'Löschen der Teilaufgabe nicht möglich.',
    'Sub-task updated successfully.' => 'Teilaufgabe erfolgreich aktualisiert.',
    'Unable to update your sub-task.' => 'Aktualisieren der Teilaufgabe nicht möglich.',
    'Unable to create your sub-task.' => 'Erstellen der Teilaufgabe nicht möglich.',
    'Maximum size: ' => 'Maximalgröße: ',
    'Display another project' => 'Zu Projekt wechseln',
    'Created by %s' => 'Erstellt durch %s',
    'Tasks Export' => 'Aufgaben exportieren',
    'Start Date' => 'Anfangsdatum',
    'Execute' => 'Ausführen',
    'Task Id' => 'Aufgaben-ID',
    'Creator' => 'Erstellt von',
    'Modification date' => 'Änderungsdatum',
    'Completion date' => 'Abschlussdatum',
    'Clone' => 'duplizieren',
    'Project cloned successfully.' => 'Projekt wurde dupliziert.',
    'Unable to clone this project.' => 'Duplizieren dieses Projekts schlug fehl.',
    'Enable email notifications' => 'E-Mail-Benachrichtigungen einschalten',
    'Task position:' => 'Position der Aufgabe:',
    'The task #%d has been opened.' => 'Die Aufgabe #%d wurde geöffnet.',
    'The task #%d has been closed.' => 'Die Aufgabe #%d wurde geschlossen.',
    'Sub-task updated' => 'Teilaufgabe aktualisiert',
    'Title:' => 'Titel:',
    'Status:' => 'Status:',
    'Assignee:' => 'Zuständigkeit:',
    'Time tracking:' => 'Zeiterfassung:',
    'New sub-task' => 'Neue Teilaufgabe',
    'New attachment added "%s"' => 'Neuer Anhang "%s" wurde hinzugefügt.',
    'New comment posted by %s' => 'Neuer Kommentar verfasst durch %s',
    'New comment' => 'Neuer Kommentar',
    'Comment updated' => 'Kommentar wurde aktualisiert',
    'New subtask' => 'Neue Teilaufgabe',
    'I only want to receive notifications for these projects:' => 'Ich möchte nur für diese Projekte Benachrichtigungen erhalten:',
    'view the task on Kanboard' => 'diese Aufgabe auf dem Kanboard zeigen',
    'Public access' => 'Öffentlicher Zugriff',
    'Disable public access' => 'Öffentlichen Zugriff deaktivieren',
    'Enable public access' => 'Öffentlichen Zugriff aktivieren',
    'Public access disabled' => 'Öffentlicher Zugriff deaktiviert',
    'Move the task to another project' => 'Aufgabe in ein anderes Projekt verschieben',
    'Move to project' => 'In anderes Projekt verschieben',
    'Do you really want to duplicate this task?' => 'Möchten Sie diese Aufgabe wirklich duplizieren?',
    'Duplicate a task' => 'Aufgabe duplizieren',
    'External accounts' => 'Externe Accounts',
    'Account type' => 'Accounttyp',
    'Local' => 'Lokal',
    'Remote' => 'Remote',
    'Enabled' => 'angeschaltet',
    'Disabled' => 'abgeschaltet',
    'Login:' => 'Benutzername:',
    'Full Name:' => 'Vollständiger Name:',
    'Email:' => 'E-Mail:',
    'Notifications:' => 'Benachrichtigungen:',
    'Notifications' => 'Benachrichtigungen',
    'Account type:' => 'Accounttyp:',
    'Edit profile' => 'Profil bearbeiten',
    'Change password' => 'Passwort ändern',
    'Password modification' => 'Passwortänderung',
    'External authentications' => 'Externe Authentisierungsmethoden',
    'Never connected.' => 'Noch nie verbunden.',
    'No external authentication enabled.' => 'Es sind keine externen Authentisierungsmethoden aktiv.',
    'Password modified successfully.' => 'Passwort wurde erfolgreich geändert.',
    'Unable to change the password.' => 'Passwort konnte nicht geändert werden.',
    'Change category' => 'Kategorie ändern',
    '%s updated the task %s' => '%s hat die Aufgabe %s aktualisiert',
    '%s opened the task %s' => '%s hat die Aufgabe %s geöffnet',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s hat die Aufgabe %s auf die Position #%d in der Spalte "%s" verschoben',
    '%s moved the task %s to the column "%s"' => '%s hat die Aufgabe %s in die Spalte "%s" verschoben',
    '%s created the task %s' => '%s hat die Aufgabe %s angelegt',
    '%s closed the task %s' => '%s hat die Aufgabe %s geschlossen',
    '%s created a subtask for the task %s' => '%s hat eine Teilaufgabe für die Aufgabe %s angelegt',
    '%s updated a subtask for the task %s' => '%s hat eine Teilaufgabe der Aufgabe %s verändert',
    'Assigned to %s with an estimate of %s/%sh' => 'An %s zugewiesen mit einer Schätzung von %s/%s Stunden',
    'Not assigned, estimate of %sh' => 'Nicht zugewiesen, Schätzung von %s Stunden',
    '%s updated a comment on the task %s' => '%s hat einen Kommentar der Aufgabe %s aktualisiert',
    '%s commented the task %s' => '%s hat die Aufgabe %s kommentiert',
    '%s\'s activity' => '%s\'s Aktivität',
    'RSS feed' => 'RSS Feed',
    '%s updated a comment on the task #%d' => '%s hat einen Kommentar der Aufgabe #%d aktualisiert',
    '%s commented on the task #%d' => '%s hat die Aufgabe #%d kommentiert',
    '%s updated a subtask for the task #%d' => '%s hat eine Teilaufgabe der Aufgabe #%d aktualisiert',
    '%s created a subtask for the task #%d' => '%s hat eine Teilaufgabe der Aufgabe #%d angelegt',
    '%s updated the task #%d' => '%s hat die Aufgabe #%d aktualisiert',
    '%s created the task #%d' => '%s hat die Aufgabe #%d angelegt',
    '%s closed the task #%d' => '%s hat die Aufgabe #%d geschlossen',
    '%s opened the task #%d' => '%s hat die Aufgabe #%d geöffnet',
    'Activity' => 'Aktivität',
    'Default values are "%s"' => 'Die Standardwerte sind "%s"',
    'Default columns for new projects (Comma-separated)' => 'Standardspalten für neue Projekte (Komma getrennt)',
    'Task assignee change' => 'Zuständigkeit geändert',
    '%s changed the assignee of the task #%d to %s' => '%s hat die Zuständigkeit der Aufgabe #%d geändert zu %s',
    '%s changed the assignee of the task %s to %s' => '%s hat die Zuständigkeit der Aufgabe %s geändert zu %s',
    'New password for the user "%s"' => 'Neues Passwort des Benutzers "%s"',
    'Choose an event' => 'Aktion wählen',
    'Create a task from an external provider' => 'Eine Aufgabe durch einen externen Provider hinzufügen',
    'Change the assignee based on an external username' => 'Zuordnung ändern basierend auf externem Benutzernamen',
    'Change the category based on an external label' => 'Kategorie basierend auf einer externen Kennzeichnung ändern',
    'Reference' => 'Referenz',
    'Label' => 'Kennzeichnung',
    'Database' => 'Datenbank',
    'About' => 'Über',
    'Database driver:' => 'Datenbanktreiber:',
    'Board settings' => 'Pinnwandeinstellungen',
    'Webhook settings' => 'Webhook-Einstellungen',
    'Reset token' => 'Token zurücksetzen',
    'API endpoint:' => 'API-Endpunkt:',
    'Refresh interval for personal board' => 'Aktualisierungsintervall für persönliche Pinnwände',
    'Refresh interval for public board' => 'Aktualisierungsintervall für öffentliche Pinnwände',
    'Task highlight period' => 'Aufgaben-Hervorhebungsdauer',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Dauer (in Sekunden), wie lange eine Aufgabe als kürzlich verändert gilt (0 um diese Funktion zu deaktivieren, standardmäßig 2 Tage)',
    'Frequency in second (60 seconds by default)' => 'Frequenz in Sekunden (standardmäßig 60 Sekunden)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frequenz in Sekunden (0 um diese Funktion zu deaktivieren, standardmäßig 10 Sekunden)',
    'Application URL' => 'Applikations-URL',
    'Token regenerated.' => 'Token wurde neu generiert.',
    'Date format' => 'Datumsformat',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO Format wird immer akzeptiert, z.B.: "%s" und "%s"',
    'New personal project' => 'Neues persönliches Projekt',
    'This project is personal' => 'Dies ist ein persönliches Projekt',
    'Add' => 'Hinzufügen',
    'Start date' => 'Startdatum',
    'Time estimated' => 'Geschätzte Zeit',
    'There is nothing assigned to you.' => 'Ihnen ist nichts zugewiesen.',
    'My tasks' => 'Meine Aufgaben',
    'Activity stream' => 'Letzte Aktivitäten',
    'Dashboard' => 'Dashboard',
    'Confirmation' => 'Wiederholung',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Kommentar eines externen Providers hinzufügen',
    'Project management' => 'Projektmanagement',
    'Columns' => 'Spalten',
    'Task' => 'Aufgabe',
    'Percentage' => 'Prozentsatz',
    'Number of tasks' => 'Anzahl an Aufgaben',
    'Task distribution' => 'Aufgabenverteilung',
    'Analytics' => 'Analyse',
    'Subtask' => 'Teilaufgabe',
    'User repartition' => 'Benutzerverteilung',
    'Clone this project' => 'Projekt kopieren',
    'Column removed successfully.' => 'Spalte erfolgreich entfernt.',
    'Not enough data to show the graph.' => 'Nicht genügend Daten, um die Grafik zu zeigen.',
    'Previous' => 'Vorherige',
    'The id must be an integer' => 'Die ID muss eine ganze Zahl sein',
    'The project id must be an integer' => 'Der Projekt-ID muss eine ganze Zahl sein',
    'The status must be an integer' => 'Der Status muss eine ganze Zahl sein',
    'The subtask id is required' => 'Die Teilaufgaben-ID ist benötigt',
    'The subtask id must be an integer' => 'Die Teilaufgaben-ID muss eine ganze Zahl sein',
    'The task id is required' => 'Die Aufgaben-ID ist benötigt',
    'The task id must be an integer' => 'Die Aufgaben-ID muss eine ganze Zahl sein',
    'The user id must be an integer' => 'Die Benutzer-ID muss eine ganze Zahl sein',
    'This value is required' => 'Dieser Wert ist erforderlich',
    'This value must be numeric' => 'Dieser Wert muss nummerisch sein',
    'Unable to create this task.' => 'Diese Aufgabe kann nicht erstellt werden',
    'Cumulative flow diagram' => 'Kumulatives Flussdiagramm',
    'Daily project summary' => 'Tägliche Projektzusammenfassung',
    'Daily project summary export' => 'Export der täglichen Projektzusammenfassung',
    'Exports' => 'Exporte',
    'This export contains the number of tasks per column grouped per day.' => 'Dieser Export enthält die Anzahl der Aufgaben pro Spalte nach Tagen gruppiert.',
    'Active swimlanes' => 'Aktive Swimlane',
    'Add a new swimlane' => 'Eine neue Swimlane hinzufügen',
    'Default swimlane' => 'Standard-Swimlane',
    'Do you really want to remove this swimlane: "%s"?' => 'Diese Swimlane wirklich entfernen: "%s"?',
    'Inactive swimlanes' => 'Inaktive Swimlane',
    'Remove a swimlane' => 'Swimlane entfernen',
    'Swimlane modification for the project "%s"' => 'Swimlane-Änderung für das Projekt "%s"',
    'Swimlane removed successfully.' => 'Swimlane erfolgreich entfernt.',
    'Swimlanes' => 'Swimlanes',
    'Swimlane updated successfully.' => 'Swimlane erfolgreich geändert.',
    'Unable to remove this swimlane.' => 'Es ist nicht möglich, die Swimlane zu entfernen.',
    'Unable to update this swimlane.' => 'Es ist nicht möglich, die Swimlane zu ändern.',
    'Your swimlane has been created successfully.' => 'Die Swimlane wurde erfolgreich angelegt.',
    'Example: "Bug, Feature Request, Improvement"' => 'Beispiel: "Bug, Funktionswünsche, Verbesserung"',
    'Default categories for new projects (Comma-separated)' => 'Standard-Kategorien für neue Projekte (Komma-getrennt)',
    'Integrations' => 'Integration',
    'Integration with third-party services' => 'Integration von externen Diensten',
    'Subtask Id' => 'Teilaufgaben-ID',
    'Subtasks' => 'Teilaufgaben',
    'Subtasks Export' => 'Export von Teilaufgaben',
    'Task Title' => 'Aufgaben-Titel',
    'Untitled' => 'unbetitelt',
    'Application default' => 'Anwendungsstandard',
    'Language:' => 'Sprache:',
    'Timezone:' => 'Zeitzone:',
    'All columns' => 'Alle Spalten',
    'Next' => 'Nächste',
    '#%d' => 'Nr %d',
    'All swimlanes' => 'Alle Swimlanes',
    'All colors' => 'Alle Farben',
    'Moved to column %s' => 'In Spalte %s verschoben',
    'User dashboard' => 'Benutzer-Dashboard',
    'Allow only one subtask in progress at the same time for a user' => 'Erlaube nur eine Teilaufgabe pro Benutzer zu bearbeiten',
    'Edit column "%s"' => 'Spalte "%s" bearbeiten',
    'Select the new status of the subtask: "%s"' => 'Wähle einen neuen Status für Teilaufgabe: "%s"',
    'Subtask timesheet' => 'Teilaufgaben Zeiterfassung',
    'There is nothing to show.' => 'Es ist nichts zum Anzeigen vorhanden.',
    'Time Tracking' => 'Zeiterfassung',
    'You already have one subtask in progress' => 'Bereits eine Teilaufgabe in Bearbeitung',
    'Which parts of the project do you want to duplicate?' => 'Welcher Teil des Projekts soll kopiert werden?',
    'Disallow login form' => 'Verbiete Login-Formular',
    'Start' => 'Start',
    'End' => 'Ende',
    'Task age in days' => 'Aufgabenalter in Tagen',
    'Days in this column' => 'Tage in dieser Spalte',
    '%dd' => '%dT',
    'Add a new link' => 'Neue Verbindung hinzufügen',
    'Do you really want to remove this link: "%s"?' => 'Die Verbindung "%s" wirklich löschen?',
    'Do you really want to remove this link with task #%d?' => 'Die Verbindung mit der Aufgabe #%d wirklich löschen?',
    'Field required' => 'Feld erforderlich',
    'Link added successfully.' => 'Verbindung erfolgreich hinzugefügt.',
    'Link updated successfully.' => 'Verbindung erfolgreich aktualisiert.',
    'Link removed successfully.' => 'Verbindung erfolgreich gelöscht.',
    'Link labels' => 'Verbindungsbeschriftung',
    'Link modification' => 'Verbindung ändern',
    'Opposite label' => 'Gegenteil',
    'Remove a link' => 'Verbindung entfernen',
    'The labels must be different' => 'Die Beschriftung muss unterschiedlich sein',
    'There is no link.' => 'Es gibt keine Verbindung',
    'This label must be unique' => 'Die Beschriftung muss einzigartig sein',
    'Unable to create your link.' => 'Verbindung kann nicht erstellt werden.',
    'Unable to update your link.' => 'Verbindung kann nicht aktualisiert werden.',
    'Unable to remove this link.' => 'Verbindung kann nicht entfernt werden',
    'relates to' => 'gehört zu',
    'blocks' => 'blockiert',
    'is blocked by' => 'ist blockiert von',
    'duplicates' => 'doppelt',
    'is duplicated by' => 'ist gedoppelt von',
    'is a child of' => 'ist ein untergeordnetes Element von',
    'is a parent of' => 'ist ein übergeordnetes Element von',
    'targets milestone' => 'betrifft Meilenstein',
    'is a milestone of' => 'ist ein Meilenstein von',
    'fixes' => 'behebt',
    'is fixed by' => 'wird behoben von',
    'This task' => 'Diese Aufgabe',
    '<1h' => '<1Std',
    '%dh' => '%dStd',
    'Expand tasks' => 'Aufgaben aufklappen',
    'Collapse tasks' => 'Aufgaben zusammenklappen',
    'Expand/collapse tasks' => 'Aufgaben auf/zuklappen',
    'Close dialog box' => 'Dialog schließen',
    'Submit a form' => 'Formular abschicken',
    'Board view' => 'Pinnwand Ansicht',
    'Keyboard shortcuts' => 'Tastaturkürzel',
    'Open board switcher' => 'Pinnwandauswahl öffnen',
    'Application' => 'Anwendung',
    'Compact view' => 'Kompaktansicht',
    'Horizontal scrolling' => 'Horizontales Scrollen',
    'Compact/wide view' => 'Kompakt/Breite-Ansicht',
    'Currency' => 'Währung',
    'Personal project' => 'privates Projekt',
    'AUD - Australian Dollar' => 'AUD - Australische Dollar',
    'CAD - Canadian Dollar' => 'CAD - Kanadische Dollar',
    'CHF - Swiss Francs' => 'CHF - Schweizer Franken',
    'Custom Stylesheet' => 'benutzerdefiniertes Stylesheet',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Britische Pfund',
    'INR - Indian Rupee' => 'INR - Indische Rupien',
    'JPY - Japanese Yen' => 'JPY - Japanische Yen',
    'NZD - New Zealand Dollar' => 'NZD - Neuseeland-Dollar',
    'PEN - Peruvian Sol' => 'PEN - Peruanischer Sol',
    'RSD - Serbian dinar' => 'RSD – Serbischer Dinar',
    'CNY - Chinese Yuan' => 'CNY - Chinesischer Yuan',
    'USD - US Dollar' => 'USD – US-Dollar',
    'VES - Venezuelan Bolívar' => 'VES - Venezolanischer Bolívar',
    'Destination column' => 'Zielspalte',
    'Move the task to another column when assigned to a user' => 'Aufgabe in eine andere Spalte verschieben, wenn ein Benutzer zugeordnet wurde.',
    'Move the task to another column when assignee is cleared' => 'Aufgabe in eine andere Spalte verschieben, wenn die Zuordnung gelöscht wurde.',
    'Source column' => 'Quellspalte',
    'Transitions' => 'Übergänge',
    'Executer' => 'Ausführender',
    'Time spent in the column' => 'Zeit in Spalte verbracht',
    'Task transitions' => 'Aufgaben-Übergänge',
    'Task transitions export' => 'Aufgaben-Übergänge exportieren',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Diese Auswertung enthält alle Spaltenbewegungen für jede Aufgabe mit Datum, Benutzer und Zeit vor jedem Wechsel.',
    'Currency rates' => 'Währungskurse',
    'Rate' => 'Kurse',
    'Change reference currency' => 'Referenzwährung ändern',
    'Reference currency' => 'Referenzwährung',
    'The currency rate has been added successfully.' => 'Der Währungskurs wurde erfolgreich hinzugefügt.',
    'Unable to add this currency rate.' => 'Währungskurs konnte nicht hinzugefügt werden',
    'Webhook URL' => 'Webhook-URL',
    '%s removed the assignee of the task %s' => '%s Zuordnung für die Aufgabe %s entfernen',
    'Information' => 'Information',
    'Check two factor authentication code' => 'Prüfe Zwei-Faktor-Authentifizierungscode',
    'The two factor authentication code is not valid.' => 'Der Zwei-Faktor-Authentifizierungscode ist ungültig.',
    'The two factor authentication code is valid.' => 'Der Zwei-Faktor-Authentifizierungscode ist gültig.',
    'Code' => 'Code',
    'Two factor authentication' => 'Zwei-Faktor-Authentifizierung',
    'This QR code contains the key URI: ' => 'Dieser QR-Code beinhaltet die Schlüssel-URI: ',
    'Check my code' => 'Überprüfe meinen Code',
    'Secret key: ' => 'Geheimer Schlüssel: ',
    'Test your device' => 'Testen Sie Ihr Gerät',
    'Assign a color when the task is moved to a specific column' => 'Weise eine Farbe zu, wenn die Aufgabe zu einer bestimmten Spalte bewegt wird',
    '%s via Kanboard' => '%s via Kanboard',
    'Burndown chart' => 'Burndown-Diagramm',
    'This chart show the task complexity over the time (Work Remaining).' => 'Dieses Diagramm zeigt die Aufgabenkomplexität über den Faktor Zeit (Verbleibende Arbeit).',
    'Screenshot taken %s' => 'Screenshot aufgenommen %s',
    'Add a screenshot' => 'Screenshot hinzufügen',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Nehmen Sie einen Screenshot auf und drücken STRG+V oder ⌘+V um ihn hier einzufügen.',
    'Screenshot uploaded successfully.' => 'Screenshot erfolgreich hochgeladen.',
    'SEK - Swedish Krona' => 'SEK - Schwedische Kronen',
    'Identifier' => 'Identifikator',
    'Disable two factor authentication' => 'Deaktiviere Zwei-Faktor-Authentifizierung',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Wollen Sie wirklich für folgenden Benutzer die Zwei-Faktor-Authentifizierung deaktivieren: "%s"?',
    'Edit link' => 'Verbindung bearbeiten',
    'Start to type task title...' => 'Beginne mit der Titeleingabe...',
    'A task cannot be linked to itself' => 'Eine Aufgabe kann nicht mit sich selber verbunden werden',
    'The exact same link already exists' => 'Diese Verbindung existiert bereits',
    'Recurrent task is scheduled to be generated' => 'Wiederkehrende Aufgabe ist zur Generierung eingeplant',
    'Score' => 'Wertung',
    'The identifier must be unique' => 'Der Schlüssel muss einzigartig sein',
    'This linked task id doesn\'t exists' => 'Die verbundene Aufgabe existiert nicht',
    'This value must be alphanumeric' => 'Der Wert muss alphanumerisch sein',
    'Edit recurrence' => 'Wiederholung bearbeiten',
    'Generate recurrent task' => 'Wiederkehrende Aufgabe generieren',
    'Trigger to generate recurrent task' => 'Auslöser für wiederkehrende Aufgabe',
    'Factor to calculate new due date' => 'Faktor zur Berechnung für neues Ablaufdatum',
    'Timeframe to calculate new due date' => 'Zeitfenster zur Berechnung für neues Ablaufdatum',
    'Base date to calculate new due date' => 'Basisdatum zur Berechnung für neues Ablaufdatum',
    'Action date' => 'Aktionsdatum',
    'Base date to calculate new due date: ' => 'Basisdatum zur Berechnung für neues Ablaufdatum: ',
    'This task has created this child task: ' => 'Diese Aufgabe hat diese Teilaufgabe erstellt: ',
    'Day(s)' => 'Tag(e)',
    'Existing due date' => 'Existierendes Ablaufdatum',
    'Factor to calculate new due date: ' => 'Faktor zur Berechnung für neues Ablaufdatum: ',
    'Month(s)' => 'Monat(e)',
    'This task has been created by: ' => 'Diese Aufgabe wurde erstellt von: ',
    'Recurrent task has been generated:' => 'Wiederkehrende Aufgabe wurde erstellt:',
    'Timeframe to calculate new due date: ' => 'Zeitfenster zur Berechnung für neues Ablaufdatum: ',
    'Trigger to generate recurrent task: ' => 'Auslöser für wiederkehrende Aufgabe: ',
    'When task is closed' => 'Wenn Aufgabe geschlossen wird',
    'When task is moved from first column' => 'Wenn Aufgabe von erster Spalte verschoben wird',
    'When task is moved to last column' => 'Wenn Aufgabe in letzte Spalte verschoben wird',
    'Year(s)' => 'Jahr(e)',
    'Project settings' => 'Projekteinstellungen',
    'Automatically update the start date' => 'Beginndatum automatisch aktualisieren',
    'iCal feed' => 'iCal Feed',
    'Preferences' => 'Einstellungen',
    'Security' => 'Sicherheit',
    'Two factor authentication disabled' => 'Zwei-Faktor-Authentifizierung deaktiviert',
    'Two factor authentication enabled' => 'Zwei-Faktor-Authentifizierung aktiviert',
    'Unable to update this user.' => 'Benutzer kann nicht bearbeitet werden',
    'There is no user management for personal projects.' => 'Es gibt keine Benutzerverwaltung für persönliche Projekte',
    'User that will receive the email' => 'Empfänger der E-Mail',
    'Email subject' => 'E-Mail-Betreff',
    'Date' => 'Datum',
    'Add a comment log when moving the task between columns' => 'Kommentar hinzufügen, wenn Aufgabe in andere Spalte verschoben wird',
    'Move the task to another column when the category is changed' => 'Aufgabe in andere Spalte verschieben, wenn Kategorie geändert wird',
    'Send a task by email to someone' => 'Aufgabe per E-Mail versenden',
    'Reopen a task' => 'Aufgabe wieder öffnen',
    'Notification' => 'Benachrichtigungen',
    '%s moved the task #%d to the first swimlane' => '%s hat die Aufgabe #%d in die erste Swimlane verschoben',
    'Swimlane' => 'Swimlane',
    '%s moved the task %s to the first swimlane' => '%s hat die Aufgabe %s in die erste Swimlane verschoben',
    '%s moved the task %s to the swimlane "%s"' => '%s hat die Aufgaben %s in die Swimlane "%s" verschoben',
    'This report contains all subtasks information for the given date range.' => 'Der Bericht beinhaltet alle Teilaufgaben im gewählten Zeitraum',
    'This report contains all tasks information for the given date range.' => 'Der Bericht beinhaltet alle Aufgaben im gewählten Zeitraum',
    'Project activities for %s' => 'Projektaktivitäten für %s',
    'view the board on Kanboard' => 'Pinnwand in Kanboard anzeigen',
    'The task has been moved to the first swimlane' => 'Die Aufgabe wurde in die erste Swimlane verschoben',
    'The task has been moved to another swimlane:' => 'Die Aufgaben wurde in eine andere Swimlane verschoben:',
    'New title: %s' => 'Neuer Titel: %s',
    'The task is not assigned anymore' => 'Die Aufgabe ist nicht mehr zugewiesen',
    'New assignee: %s' => 'Neue Zuordnung: %s',
    'There is no category now' => 'Es gibt keine Kategorie im Moment',
    'New category: %s' => 'Neue Kategorie: %s',
    'New color: %s' => 'Neue Farbe: %s',
    'New complexity: %d' => 'Neue Komplexität: %d',
    'The due date has been removed' => 'Das Ablaufdatum wurde entfernt',
    'There is no description anymore' => 'Es gibt keine Beschreibung mehr',
    'Recurrence settings has been modified' => 'Die Einstellungen für Wiederholung wurden geändert',
    'Time spent changed: %sh' => 'Verbrauchte Zeit geändert: %sh',
    'Time estimated changed: %sh' => 'Geschätzte Zeit geändert: %sh',
    'The field "%s" has been updated' => 'Das Feld "%s" wurde verändert',
    'The description has been modified:' => 'Die Beschreibung wurde geändert:',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Soll die Aufgabe "%s" wirklich geschlossen werden? (einschließlich Teilaufgaben)',
    'I want to receive notifications for:' => 'Ich möchte Benachrichtigungen erhalten für:',
    'All tasks' => 'Alle Aufgaben',
    'Only for tasks assigned to me' => 'nur mir zugeordnete Aufgaben',
    'Only for tasks created by me' => 'nur von mir erstellte Aufgaben',
    'Only for tasks created by me and tasks assigned to me' => 'nur mir zugeordnete und von mir erstellte Aufgaben',
    '%%Y-%%m-%%d' => '%%d.%%m.%%Y',
    'Total for all columns' => 'Gesamt für alle Spalten',
    'You need at least 2 days of data to show the chart.' => 'Es werden mindestens 2 Tage zur Darstellung benötigt',
    '<15m' => '<15min',
    '<30m' => '<30min',
    'Stop timer' => 'Stoppe Timer',
    'Start timer' => 'Starte Timer',
    'My activity stream' => 'Aktivitätsstream',
    'Search tasks' => 'Suche nach Aufgaben',
    'Reset filters' => 'Filter zurücksetzen',
    'My tasks due tomorrow' => 'Meine morgen fälligen Aufgaben',
    'Tasks due today' => 'Heute fällige Aufgaben',
    'Tasks due tomorrow' => 'Morgen fällige Aufgaben',
    'Tasks due yesterday' => 'Gestern fällige Aufgaben',
    'Closed tasks' => 'Abgeschlossene Aufgaben',
    'Open tasks' => 'Offene Aufgaben',
    'Not assigned' => 'Nicht zugewiesen',
    'View advanced search syntax' => 'Zur erweiterten Suchsyntax',
    'Overview' => 'Überblick',
    'Board/Calendar/List view' => 'Board-/Kalender-/Listen-Ansicht',
    'Switch to the board view' => 'Zur Board-Ansicht',
    'Switch to the list view' => 'Zur Listen-Ansicht',
    'Go to the search/filter box' => 'Zum Such- und Filterfeld',
    'There is no activity yet.' => 'Es gibt bislang keine Aktivitäten.',
    'No tasks found.' => 'Keine Aufgaben gefunden.',
    'Keyboard shortcut: "%s"' => 'Tastaturkürzel: "%s"',
    'List' => 'Liste',
    'Filter' => 'Filter',
    'Advanced search' => 'Fortgeschrittene Suche',
    'Example of query: ' => 'Beispiel einer Abfrage: ',
    'Search by project: ' => 'Suche nach Projekt: ',
    'Search by column: ' => 'Suche nach Spalte: ',
    'Search by assignee: ' => 'Suche nach zugeordnetem Benutzer: ',
    'Search by color: ' => 'Suche nach Farbe: ',
    'Search by category: ' => 'Suche nach Kategorie: ',
    'Search by description: ' => 'Suche nach Beschreibung: ',
    'Search by due date: ' => 'Suche nach Fälligkeitsdatum: ',
    'Average time spent in each column' => 'Durchschnittszeit in jeder Spalte',
    'Average time spent' => 'Durchschnittlicher Zeitverbrauch',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Dieses Diagramm zeigt die durchschnittliche Zeit in jeder Spalte der letzten %d Aufgaben.',
    'Average Lead and Cycle time' => 'Durchschnittliche Zyklus- und Durchlaufzeit',
    'Average lead time: ' => 'Durchschnittliche Durchlaufzeit: ',
    'Average cycle time: ' => 'Durchschnittliche Zykluszeit: ',
    'Cycle Time' => 'Zykluszeit',
    'Lead Time' => 'Durchlaufzeit',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Das Diagramm zeigt die durchschnittliche Durchlauf- und Zykluszeit der letzten %d Aufgaben über die Zeit an.',
    'Average time into each column' => 'Durchschnittszeit in jeder Spalte',
    'Lead and cycle time' => 'Durchlauf- und Zykluszeit',
    'Lead time: ' => 'Durchlaufzeit: ',
    'Cycle time: ' => 'Zykluszeit: ',
    'Time spent in each column' => 'zeit verbracht in jeder Spalte',
    'The lead time is the duration between the task creation and the completion.' => 'Die Durchlaufzeit ist die Dauer zwischen Erstellung und Fertigstellung.',
    'The cycle time is the duration between the start date and the completion.' => 'Die Zykluszeit ist die Dauer zwischen Start und Fertigstellung.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Wenn die Aufgabe nicht geschlossen ist, wird die aktuelle Zeit statt der Fertigstellung verwendet.',
    'Set the start date automatically' => 'Setze Startdatum automatisch',
    'Edit Authentication' => 'Authentifizierung bearbeiten',
    'Remote user' => 'Remote-Benutzer',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Remote-Benutzer haben kein Passwort in der Kanboard Datenbank, Beispiel: LDAP, Google und Github Accounts',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Wenn die Box "Verbiete Login-Formular" angeschaltet ist, werden Eingaben in das Login Formular ignoriert.',
    'Default task color' => 'Voreingestellte Aufgabenfarbe',
    'This feature does not work with all browsers.' => 'Diese Funktion funktioniert nicht mit allen Browsern',
    'There is no destination project available.' => 'Es ist kein Zielprojekt vorhanden.',
    'Trigger automatically subtask time tracking' => 'Teilaufgaben Zeiterfassung automatisch starten',
    'Include closed tasks in the cumulative flow diagram' => 'Geschlossen Aufgaben ins kumulative Flussdiagramm einschließen',
    'Current swimlane: %s' => 'Aktuelle Swimlane: %s',
    'Current column: %s' => 'Aktuelle Spalte: %s',
    'Current category: %s' => 'Aktuelle Kategorie: %s',
    'no category' => 'keine Kategorie',
    'Current assignee: %s' => 'Aktuelle Zuordnung: %s',
    'not assigned' => 'nicht zugeordnet',
    'Author:' => 'Autor:',
    'contributors' => 'Mitwirkende',
    'License:' => 'Lizenz:',
    'License' => 'Lizenz',
    'Enter the text below' => 'Text unten eingeben',
    'Start date:' => 'Startdatum:',
    'Due date:' => 'Ablaufdatum:',
    'People who are project managers' => 'Benutzer die Projektmanager sind',
    'People who are project members' => 'Benutzer die Projektmitglieder sind',
    'NOK - Norwegian Krone' => 'NOK - Norwegische Kronen',
    'Show this column' => 'Spalte anzeigen',
    'Hide this column' => 'Spalte verstecken',
    'End date' => 'Endedatum',
    'Users overview' => 'Benutzerübersicht',
    'Members' => 'Mitglieder',
    'Shared project' => 'Geteiltes Projekt',
    'Project managers' => 'Projektmanager',
    'Projects list' => 'Projektliste',
    'End date:' => 'Endedatum:',
    'Change task color when using a specific task link' => 'Aufgabefarbe ändern bei bestimmter Aufgabenverbindung',
    'Task link creation or modification' => 'Aufgabenverbindung erstellen oder bearbeiten',
    'Milestone' => 'Meilenstein',
    'Reset the search/filter box' => 'Suche/Filter-Box zurücksetzen',
    'Documentation' => 'Dokumentation',
    'Author' => 'Autor',
    'Version' => 'Version',
    'Plugins' => 'Plugins',
    'There is no plugin loaded.' => 'Es ist kein Plugin geladen.',
    'My notifications' => 'Meine Benachrichtigungen',
    'Custom filters' => 'Benutzerdefinierte Filter',
    'Your custom filter has been created successfully.' => 'Benutzerdefinierten Filter erfolgreich erstellt.',
    'Unable to create your custom filter.' => 'Benutzerdefinierter Filter konnte nicht erstellt werden.',
    'Custom filter removed successfully.' => 'Benutzerdefinierten Filter erfolgreich entfernt.',
    'Unable to remove this custom filter.' => 'Benutzerdefinierten Filter konnte nicht entfernt werden.',
    'Edit custom filter' => 'Benutzerdefinierten Filter bearbeiten',
    'Your custom filter has been updated successfully.' => 'Benutzerdefinierten Filter erfolgreich bearbeitet.',
    'Unable to update custom filter.' => 'Benutzerdefinierter Filter konnte nicht geändert werden.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Neuer Anhang für Aufgabe #%d: %s',
    'New comment on task #%d' => 'Neuer Kommentar für Aufgabe #%d',
    'Comment updated on task #%d' => 'Kommentar geändert für Aufgabe #%d',
    'New subtask on task #%d' => 'Neue Teilaufgabe für Aufgabe #%d',
    'Subtask updated on task #%d' => 'Teilaufgabe geändert für Aufgabe #%d',
    'New task #%d: %s' => 'Neue Aufgabe #%d: %s',
    'Task updated #%d' => 'Aufgabe bearbeitet #%d',
    'Task #%d closed' => 'Aufgabe #%d geschlossen',
    'Task #%d opened' => 'Aufgabe #%d eröffnet',
    'Column changed for task #%d' => 'Spalte geändert von Aufgabe #%d',
    'New position for task #%d' => 'Neue Position für Aufgabe #%d',
    'Swimlane changed for task #%d' => 'Neue Swimlane für Aufgabe #%d',
    'Assignee changed on task #%d' => 'Neue Zuordnung für Aufgabe #%d ',
    '%d overdue tasks' => '%d überfällige Aufgaben',
    'No notification.' => 'Keine neuen Benachrichtigungen',
    'Mark all as read' => 'Alles als gelesen markieren',
    'Mark as read' => 'Als gelesen markieren',
    'Total number of tasks in this column across all swimlanes' => 'Anzahl an Aufgaben in dieser Spalte über alle Swimlanes',
    'Collapse swimlane' => 'Swimlane einklappen',
    'Expand swimlane' => 'Swimlane ausklappen',
    'Add a new filter' => 'Neuen Filter hinzufügen',
    'Share with all project members' => 'Mit allen Projektmitgliedern teilen.',
    'Shared' => 'Geteilt',
    'Owner' => 'Eigentümer',
    'Unread notifications' => 'Ungelesene Benachrichtigungen',
    'Notification methods:' => 'Benachrichtigungs-Methoden:',
    'Unable to read your file' => 'Die Datei kann nicht gelesen werden',
    '%d task(s) have been imported successfully.' => '%d Aufgabe(n) wurde(n) erfolgreich importiert',
    'Nothing has been imported!' => 'Es wurde nichts importiert!',
    'Import users from CSV file' => 'Importiere Benutzer aus CSV Datei',
    '%d user(s) have been imported successfully.' => '%d Benutzer wurde(n) erfolgreich importiert.',
    'Comma' => 'Komma',
    'Semi-colon' => 'Semikolon',
    'Tab' => 'Tabulator',
    'Vertical bar' => 'senkrechter Strich',
    'Double Quote' => 'Doppelte Anführungszeichen',
    'Single Quote' => 'Einfache Anführungszeichen',
    '%s attached a file to the task #%d' => '%s hat eine Datei zur Aufgabe #%d hinzugefügt',
    'There is no column or swimlane activated in your project!' => 'Es ist keine Spalte oder Swimlane in Ihrem Projekt aktiviert!',
    'Append filter (instead of replacement)' => 'Filter anhängen (statt zu ersetzen)',
    'Append/Replace' => 'Anhängen/Ersetzen',
    'Append' => 'Anhängen',
    'Replace' => 'Ersetzen',
    'Import' => 'Import',
    'Change sorting' => 'Sortierung ändern',
    'Tasks Importation' => 'Aufgaben Import',
    'Delimiter' => 'Trennzeichen',
    'Enclosure' => 'Textbegrenzer',
    'CSV File' => 'CSV Datei',
    'Instructions' => 'Anweisungen',
    'Your file must use the predefined CSV format' => 'Ihre Datei muss das vorgegebene CSV Format haben',
    'Your file must be encoded in UTF-8' => 'Ihre Datei muss UTF-8 kodiert sein',
    'The first row must be the header' => 'Die erste Zeile muss die Kopfzeile sein',
    'Duplicates are not verified for you' => 'Duplikate werden nicht für Sie geprüft',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Das Fälligkeitsdatum muss das ISO Format haben: YYYY-MM-DD',
    'Download CSV template' => 'CSV Vorlage herunterladen',
    'No external integration registered.' => 'Keine externe Integration registriert',
    'Duplicates are not imported' => 'Duplikate wurden nicht importiert',
    'Usernames must be lowercase and unique' => 'Benutzernamen müssen in Kleinbuchstaben und eindeutig sein',
    'Passwords will be encrypted if present' => 'Passwörter werden verschlüsselt wenn vorhanden',
    '%s attached a new file to the task %s' => '%s hat eine neue Datei zur Aufgabe %s hinzugefügt',
    'Link type' => 'Verbindungstyp',
    'Assign automatically a category based on a link' => 'Linkbasiert eine Kategorie automatisch zuordnen',
    'BAM - Konvertible Mark' => 'BAM - Konvertible Mark',
    'Assignee Username' => 'Benutzername des Zuständigen',
    'Assignee Name' => 'Name des Zuständigen',
    'Groups' => 'Gruppen',
    'Members of %s' => 'Mitglied von %s',
    'New group' => 'Neue Gruppe',
    'Group created successfully.' => 'Gruppe erfolgreich angelegt.',
    'Unable to create your group.' => 'Gruppe konnte nicht angelegt werden',
    'Edit group' => 'Gruppe bearbeiten',
    'Group updated successfully.' => 'Gruppe erfolgreich aktualisiert',
    'Unable to update your group.' => 'Gruppe konnte nicht aktualisiert werden',
    'Add group member to "%s"' => 'Gruppenmitglied zu "%s" hinzufügen',
    'Group member added successfully.' => 'Gruppenmitglied erfolgreich hinzugefügt',
    'Unable to add group member.' => 'Gruppenmitglied konnte nicht hinzugefügt werden.',
    'Remove user from group "%s"' => 'Benutzer aus Gruppe "%s" löschen',
    'User removed successfully from this group.' => 'Benutzer erfolgreich aus dieser Gruppe gelöscht.',
    'Unable to remove this user from the group.' => 'Benutzer konnte nicht aus dieser Gruppe gelöscht werden.',
    'Remove group' => 'Gruppe löschen',
    'Group removed successfully.' => 'Gruppe erfolgreich gelöscht.',
    'Unable to remove this group.' => 'Gruppe konnte nicht gelöscht werden.',
    'Project Permissions' => 'Projekt Berechtigungen',
    'Manager' => 'Manager',
    'Project Manager' => 'Projekt Manager',
    'Project Member' => 'Projekt Mitglied',
    'Project Viewer' => 'Projekt Betrachter',
    'Your account is locked for %d minutes' => 'Ihr Zugang wurde für %d Minuten gesperrt',
    'Invalid captcha' => 'Ungültiges Captcha',
    'The name must be unique' => 'Der Name muss eindeutig sein',
    'View all groups' => 'Alle Gruppen anzeigen',
    'There is no user available.' => 'Es ist kein Benutzer verfügbar.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Wollen Sie den Benutzer "%s" wirklich aus der Gruppe "%s" löschen?',
    'There is no group.' => 'Es gibt keine Gruppe.',
    'Add group member' => 'Gruppenmitglied hinzufügen',
    'Do you really want to remove this group: "%s"?' => 'Wollen Sie die Gruppe "%s" wirklich löschen?',
    'There is no user in this group.' => 'Es gibt keinen Benutzer in dieser Gruppe.',
    'Permissions' => 'Berechtigungen',
    'Allowed Users' => 'Berechtigte Benutzer',
    'No specific user has been allowed.' => 'Keine Benutzer mit ausdrücklicher Berechtigung.',
    'Role' => 'Rolle',
    'Enter user name...' => 'Geben Sie den Benutzernamen ein...',
    'Allowed Groups' => 'Berechtigte Gruppen',
    'No group has been allowed.' => 'Keine Gruppen mit ausdrücklicher Berechtigung.',
    'Group' => 'Gruppe',
    'Group Name' => 'Gruppenname',
    'Enter group name...' => 'Geben Sie den Gruppennamen ein...',
    'Role:' => 'Rolle:',
    'Project members' => 'Projektmitglieder',
    '%s mentioned you in the task #%d' => '%s erwähnte Sie in Aufgabe #%d',
    '%s mentioned you in a comment on the task #%d' => '%s erwähnte Sie in einem Kommentar zur Aufgabe #%d',
    'You were mentioned in the task #%d' => 'Sie wurden in der Aufgabe #%d erwähnt',
    'You were mentioned in a comment on the task #%d' => 'Sie wurden in einem Kommentar zur Aufgabe #%d erwähnt',
    'Estimated hours: ' => 'Erwarteter Zeitaufwand (Stunden): ',
    'Actual hours: ' => 'Tatsächlich aufgewendete Stunden: ',
    'Hours Spent' => 'Stunden aufgewendet',
    'Hours Estimated' => 'Stunden erwartet',
    'Estimated Time' => 'Erwartete Zeit',
    'Actual Time' => 'Aktuelle Zeit',
    'Estimated vs actual time' => 'Erwarteter vs. tatsächlicher Zeitaufwand',
    'RUB - Russian Ruble' => 'RUB - Russische Rubel',
    'Assign the task to the person who does the action when the column is changed' => 'Aufgabe der Person zuordnen, die die Aktion durchführt, wenn die Spalte geändert wird',
    'Close a task in a specific column' => 'Schließe eine Aufgabe in einer bestimmten Spalte',
    'Time-based One-time Password Algorithm' => 'Zeitbasierter Einmalpasswort Algorithmus',
    'Two-Factor Provider: ' => '2FA Anbieter: ',
    'Disable two-factor authentication' => 'Zwei-Faktor-Authentifizierung deaktivieren',
    'Enable two-factor authentication' => 'Zwei-Faktor-Authentifizierung aktivieren',
    'There is no integration registered at the moment.' => 'Derzeit ist kein externer Dienst registriert.',
    'Password Reset for Kanboard' => 'Zurücksetzen des Passwortes für Kanboard',
    'Forgot password?' => 'Passwort vergessen?',
    'Enable "Forget Password"' => 'Passwortrücksetzung aktivieren',
    'Password Reset' => 'Passwort zurücksetzen',
    'New password' => 'Neues Passwort',
    'Change Password' => 'Passwort ändern',
    'To reset your password click on this link:' => 'Bitte auf den Link klicken, um Ihr Passwort zurückzusetzen.',
    'Last Password Reset' => 'Verlauf der Passwortrücksetzung',
    'The password has never been reinitialized.' => 'Das Passwort wurde noch nie zurückgesetzt.',
    'Creation' => 'Erstellung',
    'Expiration' => 'Ablauf',
    'Password reset history' => 'Verlauf Passwortrücksetzung',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Alle Aufgaben der Spalte "%s" und der Swimlane "%s" wurden erfolgreich geschlossen',
    'Do you really want to close all tasks of this column?' => 'Wollen Sie wirklich alle Aufgaben in dieser Spalte schließen?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d Aufgabe(n) in der Spalte "%s" und in der Swimlane "%s" werden geschlossen.',
    'Close all tasks in this column and this swimlane' => 'Alle Aufgaben in dieser Spalte schließen',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Kein Plugin hat eine Projekt-Benachrichtigungsmethode registriert. Sie können individuelle Meldungen in Ihrem Benutzerprofil konfigurieren',
    'My dashboard' => 'Mein Dashboard',
    'My profile' => 'Mein Profil',
    'Project owner: ' => 'Projekt-Besitzer: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Die Projekt-Kennung ist optional und muss alphanumerisch sein, beispielsweise: MYPROJECT.',
    'Project owner' => 'Projekt-Besitzer',
    'Personal projects do not have users and groups management.' => 'Private Projekte haben kein Benutzer- und Gruppen-Management.',
    'There is no project member.' => 'Es gibt kein Projekt-Mitglied.',
    'Priority' => 'Priorität',
    'Task priority' => 'Aufgaben-Priorität',
    'General' => 'Allgemein',
    'Dates' => 'Daten',
    'Default priority' => 'Standard-Priorität',
    'Lowest priority' => 'Niedrigste Priorität',
    'Highest priority' => 'Höchste Priorität',
    'Close a task when there is no activity' => 'Schließe eine Aufgabe, wenn keine Aktivitäten vorhanden sind',
    'Duration in days' => 'Dauer in Tagen',
    'Send email when there is no activity on a task' => 'Versende eine E-Mail, wenn keine Aktivitäten an einer Aufgabe vorhanden sind',
    'Unable to fetch link information.' => 'Kann keine Informationen über Verbindungen holen',
    'Daily background job for tasks' => 'Tägliche Hintergrundarbeit für Aufgaben',
    'Auto' => 'Auto',
    'Related' => 'Verbunden',
    'Attachment' => 'Anhang',
    'Title not found' => 'Titel nicht gefunden',
    'Web Link' => 'Weblink',
    'External links' => 'Externe Verbindungen',
    'Add external link' => 'Externe Verbindung hinzufügen',
    'Type' => 'Typ',
    'Dependency' => 'Abhängigkeit',
    'Add internal link' => 'Interne Verbindung hinzufügen',
    'Add a new external link' => 'Füge eine neue externe Verbindung hinzu',
    'Edit external link' => 'Externe Verbindung bearbeiten',
    'External link' => 'Externe Verbindung',
    'Copy and paste your link here...' => 'Kopieren Sie Ihren Link hierher...',
    'URL' => 'URL',
    'Internal links' => 'Interne Verbindungen',
    'Assign to me' => 'Mir zuweisen',
    'Me' => 'Mich',
    'Do not duplicate anything' => 'Nichts duplizieren',
    'Projects management' => 'Projektmanagement',
    'Users management' => 'Benutzermanagement',
    'Groups management' => 'Gruppenmanagement',
    'Create from another project' => 'Von einem anderen Projekt erstellen',
    'open' => 'offen',
    'closed' => 'geschlossen',
    'Priority:' => 'Priorität:',
    'Reference:' => 'Referenz:',
    'Complexity:' => 'Komplexität:',
    'Swimlane:' => 'Swimlane:',
    'Column:' => 'Spalte:',
    'Position:' => 'Position:',
    'Creator:' => 'Ersteller:',
    'Time estimated:' => 'Geschätzte Zeit:',
    '%s hours' => '%s Stunden',
    'Time spent:' => 'Aufgewendete Zeit:',
    'Created:' => 'Erstellt:',
    'Modified:' => 'Geändert:',
    'Completed:' => 'Abgeschlossen:',
    'Started:' => 'Gestartet:',
    'Moved:' => 'Verschoben:',
    'Task #%d' => 'Aufgabe #%d',
    'Time format' => 'Zeitformat',
    'Start date: ' => 'Anfangsdatum: ',
    'End date: ' => 'Enddatum: ',
    'New due date: ' => 'Neues Fälligkeitsdatum: ',
    'Start date changed: ' => 'Anfangsdatum geändert: ',
    'Disable personal projects' => 'Persönliche Projekte deaktivieren',
    'Do you really want to remove this custom filter: "%s"?' => 'Wollen Sie diesen benutzerdefinierten Filter wirklich entfernen: "%s"?',
    'Remove a custom filter' => 'Benutzerdefinierten Filter entfernen',
    'User activated successfully.' => 'Benutzer erfolgreich aktiviert.',
    'Unable to enable this user.' => 'Dieser Benutzer kann nicht aktiviert werden.',
    'User disabled successfully.' => 'Benutzer erfolgreich deaktiviert.',
    'Unable to disable this user.' => 'Dieser Benutzer kann nicht deaktiviert werden.',
    'All files have been uploaded successfully.' => 'Alle Dateien wurden erfolgreich hochgeladen.',
    'The maximum allowed file size is %sB.' => 'Die maximal erlaubte Dateigröße ist %sB.',
    'Drag and drop your files here' => 'Ziehen Sie Ihre Dateien hier hin',
    'choose files' => 'Dateien auswählen',
    'View profile' => 'Profil ansehen',
    'Two Factor' => 'Zwei-Faktor',
    'Disable user' => 'Benutzer deaktivieren',
    'Do you really want to disable this user: "%s"?' => 'Wollen Sie diesen Benutzer wirklich deaktivieren: "%s"?',
    'Enable user' => 'Benutzer aktivieren',
    'Do you really want to enable this user: "%s"?' => 'Wollen Sie diesen Benutzer wirklich aktivieren: "%s"?',
    'Download' => 'Herunterladen',
    'Uploaded: %s' => 'Hochgeladen: %s',
    'Size: %s' => 'Größe: %s',
    'Uploaded by %s' => 'Hochgeladen von %s',
    'Filename' => 'Dateiname',
    'Size' => 'Größe',
    'Column created successfully.' => 'Spalte erfolgreich erstellt.',
    'Another column with the same name exists in the project' => 'Es gibt bereits eine Spalte mit demselben Namen im Projekt',
    'Default filters' => 'Standard-Filter',
    'Your board doesn\'t have any columns!' => 'Es gibt keine Spalten in diesem Projekt!',
    'Change column position' => 'Position der Spalte ändern',
    'Switch to the project overview' => 'Zur Projektübersicht wechseln',
    'User filters' => 'Benutzer-Filter',
    'Category filters' => 'Kategorie-Filter',
    'Upload a file' => 'Eine Datei hochladen',
    'View file' => 'Datei ansehen',
    'Last activity' => 'Letzte Aktivität',
    'Change subtask position' => 'Position der Teilaufgabe ändern',
    'This value must be greater than %d' => 'Dieser Wert muss größer als %d sein',
    'Another swimlane with the same name exists in the project' => 'Es gibt bereits eine Swimlane mit diesem Namen im Projekt',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Beispiel: https://example.kanboard.org/ (wird zum Erstellen absoluter URLs genutzt)',
    'Actions duplicated successfully.' => 'Aktionen erfolgreich dupliziert',
    'Unable to duplicate actions.' => 'Aktionen können nicht dupliziert werden.',
    'Add a new action' => 'Neue Aktion hinzufügen',
    'Import from another project' => 'Von einem anderen Projekt importieren',
    'There is no action at the moment.' => 'Es gibt zur Zeit keine Aktionen.',
    'Import actions from another project' => 'Aktionen von einem anderen Projekt importieren',
    'There is no available project.' => 'Es ist kein Projekt verfügbar.',
    'Local File' => 'Lokale Datei',
    'Configuration' => 'Konfiguration',
    'PHP version:' => 'PHP Version:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'OS Version:',
    'Database version:' => 'Datenbank Version:',
    'Browser:' => 'Browser:',
    'Task view' => 'Aufgaben Ansicht',
    'Edit task' => 'Aufgabe bearbeiten',
    'Edit description' => 'Beschreibung bearbeiten',
    'New internal link' => 'Neue interne Verbindung',
    'Display list of keyboard shortcuts' => 'Liste der Tastaturkürzel anzeigen',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Mein Avatar Bild hochladen',
    'Remove my image' => 'Mein Bild entfernen',
    'The OAuth2 state parameter is invalid' => 'Der OAuth2 Statusparameter ist ungültig',
    'User not found.' => 'Benutzer nicht gefunden',
    'Search in activity stream' => 'Im Aktivitätenstrom suchen',
    'My activities' => 'Meine Aktivitäten',
    'Activity until yesterday' => 'Aktivitäten bis gestern',
    'Activity until today' => 'Aktivitäten bis heute',
    'Search by creator: ' => 'nach Ersteller suchen:',
    'Search by creation date: ' => 'nach Datum suchen:',
    'Search by task status: ' => 'nach Aufgabenstatus suchen:',
    'Search by task title: ' => 'nach Titel suchen:',
    'Activity stream search' => 'Im Aktivitätenstrom suchen',
    'Projects where "%s" is manager' => 'Projekte in denen "%s" Manager ist',
    'Projects where "%s" is member' => 'Projekte in denen "%s" Mitglied ist',
    'Open tasks assigned to "%s"' => 'Offene Aufgaben, die "%s" zugeteilt sind',
    'Closed tasks assigned to "%s"' => 'Geschlossene Aufgaben, die "%s" zugeteilt sind',
    'Assign automatically a color based on a priority' => 'Eine Farbe basierend auf einer Priorität automatisch zuordnen',
    'Overdue tasks for the project(s) "%s"' => 'Überfällige Aufgaben des/der Projekt/e "%s"',
    'Upload files' => 'Dateien hochladen',
    'Installed Plugins' => 'Installierte Plugins',
    'Plugin Directory' => 'Plugin Verzeichnis',
    'Plugin installed successfully.' => 'Plugin erfolgreich installiert.',
    'Plugin updated successfully.' => 'Plugin erfolgreich aktualisiert.',
    'Plugin removed successfully.' => 'Plugin erfolgreich entfernt.',
    'Subtask converted to task successfully.' => 'Teilaufgabe erfolgreich in Aufgabe umgewandelt.',
    'Unable to convert the subtask.' => 'Teilaufgabe kann nicht umgewandelt werden.',
    'Unable to extract plugin archive.' => 'Plugin Archiv kann nicht entpackt werden.',
    'Plugin not found.' => 'Plugin nicht gefunden.',
    'You don\'t have the permission to remove this plugin.' => 'Sie dürfen dieses Plugin nicht entfernen.',
    'Unable to download plugin archive.' => 'Plugin Archiv kann nicht herunter geladen werden.',
    'Unable to write temporary file for plugin.' => 'Temporäre Dateien für das Plugin können nicht geschrieben werden.',
    'Unable to open plugin archive.' => 'Kann das Plugin Archiv nicht öffnen.',
    'There is no file in the plugin archive.' => 'Es gibt keine Datei im Plugin Archiv.',
    'Create tasks in bulk' => 'Viele Aufgaben auf einmal erstellen',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Ihre Kanboard Installation ist nicht dafür konfiguriert, Plugins mit dem Benutzerinterface zu installieren.',
    'There is no plugin available.' => 'Es gibt kein Plugin.',
    'Install' => 'Installieren',
    'Update' => 'Aktualisieren',
    'Up to date' => 'Aktuell',
    'Not available' => 'Nicht verfügbar',
    'Remove plugin' => 'Plugin entfernen',
    'Do you really want to remove this plugin: "%s"?' => 'Wollen Sie das Plugin "%s" wirklich entfernen?',
    'Uninstall' => 'Deinstallieren',
    'Listing' => 'Auflistung',
    'Metadata' => 'Metadaten',
    'Manage projects' => 'Projekte verwalten',
    'Convert to task' => 'In Aufgabe umwandeln',
    'Convert sub-task to task' => 'Teilaufgabe in Aufgabe umwandeln',
    'Do you really want to convert this sub-task to a task?' => 'Wollen Sie diese Teilaufgabe wirklich in eine Aufgabe umwandeln?',
    'My task title' => 'Mein Aufgabentitel',
    'Enter one task by line.' => 'Geben Sie eine Aufgabe pro Zeile ein.',
    'Number of failed login:' => 'Anzahl fehlgeschlagener Anmeldungen:',
    'Account locked until:' => 'Konto gesperrt bis:',
    'Email settings' => 'E-Mail Einstellungen',
    'Email sender address' => 'E-Mail Absender Adresse',
    'Email transport' => 'E-Mail Verkehr',
    'Webhook token' => 'Webhook Token',
    'Project tags management' => 'Projektbezogenes Schlagwort-Management',
    'Tag created successfully.' => 'Schlagwort erfolgreich erstellt.',
    'Unable to create this tag.' => 'Das Schlagwort kann nicht erstellt werden.',
    'Tag updated successfully.' => 'Schlagwort erfolgreich aktualisiert.',
    'Unable to update this tag.' => 'Das Schlagwort kann nicht aktualisiert werden.',
    'Tag removed successfully.' => 'Schlagwort erfolgreich entfernt.',
    'Unable to remove this tag.' => 'Das Schlagwort kann nicht entfernt werden.',
    'Global tags management' => 'Globales Schlagwort-Management',
    'Tags' => 'Schlagworte',
    'Tags management' => 'Schlagwort-Management',
    'Add new tag' => 'Neues Schlagwort hinzufügen',
    'Edit a tag' => 'Schlagwort bearbeiten',
    'Project tags' => 'Projektbezogene Schlagwörter',
    'There is no specific tag for this project at the moment.' => 'Es gibt zur Zeit kein spezifisches Schlagwort.',
    'Tag' => 'Schlagwort',
    'Remove a tag' => 'Schlagwort entfernen',
    'Do you really want to remove this tag: "%s"?' => 'Soll dieses Schlagwort wirklich entfernt werden: "%s"?',
    'Global tags' => 'Globale Schlagwörter',
    'There is no global tag at the moment.' => 'Es gibt zur Zeit kein globales Schlagwort',
    'This field cannot be empty' => 'Dieses Feld kann nicht leer sein',
    'Close a task when there is no activity in a specific column' => 'Aufgabe schließen wenn es keine Aktivität in einer bestimmten Spalte gibt',
    '%s removed a subtask for the task #%d' => '%s hat eine Teilaufgabe der Aufgabe #%d entfernt',
    '%s removed a comment on the task #%d' => '%s hat einen Kommentar der Aufgabe #%d entfernt',
    'Comment removed on task #%d' => 'Kommentar der Aufgabe #%d entfernt',
    'Subtask removed on task #%d' => 'Teilaufgabe der Aufgabe #%d entfernt',
    'Hide tasks in this column in the dashboard' => 'Aufgaben in dieser Spalte im Dashboard ausblenden',
    '%s removed a comment on the task %s' => '%s hat einen Kommentar in der Aufgabe %s entfernt',
    '%s removed a subtask for the task %s' => '%s hat eine Teilaufgabe in der Aufgabe %s entfernt',
    'Comment removed' => 'Kommentar entfernt',
    'Subtask removed' => 'Teilaufgabe entfernt',
    '%s set a new internal link for the task #%d' => '%s hat eine neue interne Verbindung in der Aufgabe #%d erstellt',
    '%s removed an internal link for the task #%d' => '%s hat eine interne Verbindung von der Aufgabe #%d entfernt',
    'A new internal link for the task #%d has been defined' => 'Eine neue interne Verbindung für die Aufgabe #%d wurde definiert',
    'Internal link removed for the task #%d' => 'Interne Verbindung in der Aufgabe #%d wurde entfernt',
    '%s set a new internal link for the task %s' => '%s hat eine neue interne Verbindung in der Aufgabe %s erstellt',
    '%s removed an internal link for the task %s' => '%s hat eine interne Verbindung von der Aufgabe %s entfernt',
    'Automatically set the due date on task creation' => 'Ablaufdatum automatisch bei Erstellung einer Aufgabe setzen',
    'Move the task to another column when closed' => 'Aufgabe in eine andere Spalte verschieben, wenn diese geschlossen wird',
    'Move the task to another column when not moved during a given period' => 'Aufgabe in eine andere Spalte verschieben, wenn diese in einer bestimmten Zeit nicht verschoben wurde',
    'Dashboard for %s' => 'Dashboard für %s',
    'Tasks overview for %s' => 'Aufgaben-Übersicht für %s',
    'Subtasks overview for %s' => 'Teilaufgaben-Übersicht für %s',
    'Projects overview for %s' => 'Projekt-Übersicht für %s',
    'Activity stream for %s' => 'Aktivitätenstrom für %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Einer Aufgabe eine Farbe zuweisen, wenn diese in eine bestimmte Swimlane verschoben wird',
    'Assign a priority when the task is moved to a specific swimlane' => 'Einer Aufgabe eine Priorität zuweisen, wenn diese in eine bestimmte Swimlane verschoben wird',
    'User unlocked successfully.' => 'Benutzer erfolgreich entsperrt.',
    'Unable to unlock the user.' => 'Benutzer kann nicht entsperrt werden.',
    'Move a task to another swimlane' => 'Aufgabe in eine andere Swimlane verschieben',
    'Creator Name' => 'Name des Erstellers',
    'Time spent and estimated' => 'Aufgewendete und erwartete Zeit',
    'Move position' => 'Position verschieben',
    'Move task to another position on the board' => 'Aufgabe an eine andere Position im Board verschieben',
    'Insert before this task' => 'Vor dieser Aufgabe einfügen',
    'Insert after this task' => 'Nach dieser Aufgabe einfügen',
    'Unlock this user' => 'Diesen Benutzer entsperren',
    'Custom Project Roles' => 'Benutzerdefinierte Projekt Rollen',
    'Add a new custom role' => 'Neue benutzerdefinierte Rolle erstellen',
    'Restrictions for the role "%s"' => 'Einschränkungen für Rolle "%s"',
    'Add a new project restriction' => 'Neue projektbezogene Einschränkung erstellen',
    'Add a new drag and drop restriction' => 'Neue Drag and Drop Einschränkung erstellen',
    'Add a new column restriction' => 'Neue spaltenbezogene Einschränkung erstellen',
    'Edit this role' => 'Diese Rolle bearbeiten',
    'Remove this role' => 'Diese Rolle entfernen',
    'There is no restriction for this role.' => 'Für diese Rolle gibt es keine Einschränkungen.',
    'Only moving task between those columns is permitted' => 'Verschieben von Aufgaben ist nur zwischen diesen Spalten erlaubt',
    'Close a task in a specific column when not moved during a given period' => 'Aufgabe in einer bestimmten Spalte schließen, wenn sie im angegebenen Zeitraum nicht verschoben wurde',
    'Edit columns' => 'Spalten bearbeiten',
    'The column restriction has been created successfully.' => 'Die Spalteneinschränkung wurde erfolgreich erstellt.',
    'Unable to create this column restriction.' => 'Erstellen der Spalteneinschränkung fehlgeschlagen.',
    'Column restriction removed successfully.' => ' Spalteneinschränkung erfolgreich entfernt.',
    'Unable to remove this restriction.' => 'Entfernen der Spalteneinschränkung fehlgeschlagen.',
    'Your custom project role has been created successfully.' => 'Benutzerdefinierte Projekt Rolle erfolgreich erstellt.',
    'Unable to create custom project role.' => 'Erstellen der benutzerdefinierten Projekt Rolle fehlgeschlagen.',
    'Your custom project role has been updated successfully.' => 'Benutzerdefinierte Projekt Rolle wurde erfolgreich geändert.',
    'Unable to update custom project role.' => 'Ändern der benutzerdefinierten Projekt Rolle fehlgeschlagen.',
    'Custom project role removed successfully.' => 'Benutzerdefinierte Projekt Rolle erfolgreich entfernt.',
    'Unable to remove this project role.' => 'Entfernen der benutzerdefinierten Projekt Rolle fehlgeschlagen.',
    'The project restriction has been created successfully.' => 'Projektbezogene Einschränkung erfolgreich erstellt.',
    'Unable to create this project restriction.' => 'Erstellen der projektbezogenen Einschränkung fehlgeschlagen.',
    'Project restriction removed successfully.' => 'Projektbezogene Einschränkung erfolgreich entfernt.',
    'You cannot create tasks in this column.' => 'Sie können in dieser Spalte keine Aufgaben erzeugen.',
    'Task creation is permitted for this column' => 'Erzeugen von Aufgaben ist für diese Spalte erlaubt.',
    'Closing or opening a task is permitted for this column' => 'Öffnen und Schließen von Aufgaben ist für diese Spalte erlaubt.',
    'Task creation is blocked for this column' => 'Erzeugen von Aufgaben ist für diese Spalte blockiert.',
    'Closing or opening a task is blocked for this column' => 'Öffnen und Schließen von Aufgaben ist für diese Spalte blockiert.',
    'Task creation is not permitted' => 'Erzeugen von Aufgaben ist nicht erlaubt.',
    'Closing or opening a task is not permitted' => 'Öffnen und Schließen von Aufgaben ist nicht erlaubt.',
    'New drag and drop restriction for the role "%s"' => 'Neue drag and drop Einschränkung für Rolle "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Benutzer mit dieser Rolle können Aufgaben nur zwischen Quell- und Zielspalte verschieben.',
    'Remove a column restriction' => 'Spaltenbezogene Einschränkung entfernen',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Wollen Sie diese Spalteneinschränkung wirklich löschen:  "%s" nach "%s"?',
    'New column restriction for the role "%s"' => 'Neue spaltenbezogene Einschränkung für Rolle "%s"',
    'Rule' => 'Regel',
    'Do you really want to remove this column restriction?' => 'Wollen Sie diese Spalteneinschränkung wirklich entfernen?',
    'Custom roles' => 'Benutzerdefinierte Rollen',
    'New custom project role' => 'Neue benutzerdefinierte Projekt Rolle',
    'Edit custom project role' => 'Benutzerdefinierte Projekt Rolle bearbeiten',
    'Remove a custom role' => 'Benutzerdefinierte Projekt Rolle entfernen',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Wollen sie diese benutzerdefinierte Rolle wirklich entfernen: "%s"? Alle Benutzer mit dieser Rolle werden zu Projekt-Mitgliedern.',
    'There is no custom role for this project.' => 'Für dieses Projekt gibt es keine benutzerdefinierten Rollen.',
    'New project restriction for the role "%s"' => 'Neue projektbezogene Einschränkung für Rolle "%s"',
    'Restriction' => 'Einschränkung',
    'Remove a project restriction' => 'Projektbezogene Einschränkung entfernen',
    'Do you really want to remove this project restriction: "%s"?' => 'Wollen Sie diese projektbezogene Einschränkung wirklich entfernen: "%s"?',
    'Duplicate to multiple projects' => 'In mehrere Projekte duplizieren',
    'This field is required' => 'Dies ist ein Pflichtfeld',
    'Moving a task is not permitted' => 'Verschieben einer Aufgabe ist nicht erlaubt',
    'This value must be in the range %d to %d' => 'Dieser Wert muss im Bereich %d bis %d sein',
    'You are not allowed to move this task.' => 'Sie haben nicht die Berechtigung, diese Aufgabe zu verschieben.',
    'API User Access' => 'API Benutzerzugriff',
    'Preview' => 'Vorschau',
    'Write' => 'Schreiben',
    'Write your text in Markdown' => 'Schreiben Sie Ihren Text in Markdown',
    'No personal API access token registered.' => 'Keine persönlichen API-Zugriffsinformationen registriert',
    'Your personal API access token is "%s"' => 'Ihre persönlichen API-Zugriffsinformationen: "%s"',
    'Remove your token' => 'Ihre Zugriffsinformationen entfernen',
    'Generate a new token' => 'Neue Zugriffsinformationen generieren',
    'Showing %d-%d of %d' => 'Zeige %d-%d von %d',
    'Outgoing Emails' => 'Ausgehende E-Mails',
    'Add or change currency rate' => 'Wechselkurs hinzufügen oder ändern',
    'Reference currency: %s' => 'Referenzwährung: %s',
    'Add custom filters' => 'Benutzerdefinierten Filter hinzufügen',
    'Export' => 'Exportieren',
    'Add link label' => 'Linkbeschreibung hinzufügen',
    'Incompatible Plugins' => 'Nicht-kompatible Plugins',
    'Compatibility' => 'Kompatibilität',
    'Permissions and ownership' => 'Berechtigungen und Besitz',
    'Priorities' => 'Prioritäten',
    'Close this window' => 'Dieses Fenster schließen',
    'Unable to upload this file.' => 'Diese Datei kann nicht hochgeladen werden',
    'Import tasks' => 'Aufgaben importieren',
    'Choose a project' => 'Wählen Sie ein Projekt',
    'Profile' => 'Profil',
    'Application role' => 'Anwendungsrolle',
    '%d invitations were sent.' => '%d Einladungen wurden gesendet.',
    '%d invitation was sent.' => '%d Einladung wurde gesendet.',
    'Unable to create this user.' => 'Dieser Benutzer kann nicht erstellt werden.',
    'Kanboard Invitation' => 'Kanboard Einladung',
    'Visible on dashboard' => 'Sichtbar auf dem Dashboard',
    'Created at:' => 'Erstellt am:',
    'Updated at:' => 'Aktualisiert am:',
    'There is no custom filter.' => 'Es gibt keinen benutzerdefinierten Filter.',
    'New User' => 'Neuer Benutzer',
    'Authentication' => 'Authentifizierung',
    'If checked, this user will use a third-party system for authentication.' => 'Wenn aktiviert, verwendet dieser Benutzer ein Drittanbieter-System für die Authentifizierung.',
    'The password is necessary only for local users.' => 'Das Passwort ist nur für lokale Benutzer erforderlich.',
    'You have been invited to register on Kanboard.' => 'Sie wurden eingeladen, sich auf Kanboard zu registrieren.',
    'Click here to join your team' => 'Klicken Sie hier, um Ihrem Team beizutreten',
    'Invite people' => 'Leute einladen',
    'Emails' => 'E-Mail',
    'Enter one email address by line.' => 'Geben Sie eine E-Mail-Adresse pro Zeile ein.',
    'Add these people to this project' => 'Füge diese Personen diesem Projekt hinzu',
    'Add this person to this project' => 'Füge diese Person diesem Projekt hinzu',
    'Sign-up' => 'Anmelden',
    'Credentials' => 'Anmeldeinformationen',
    'New user' => 'Neuer Benutzer',
    'This username is already taken' => 'Dieser Benutzername ist bereits vergeben',
    'Your profile must have a valid email address.' => 'Ihr Profil muss eine gültige E-Mail-Adresse haben.',
    'TRL - Turkish Lira' => 'TRL - Türkische Lira',
    'The project email is optional and could be used by several plugins.' => 'Die Projekt-E-Mail ist optional und kann von mehreren Plugins verwendet werden.',
    'The project email must be unique across all projects' => 'Die Projekt-E-Mail muss für alle Projekte eindeutig sein',
    'The email configuration has been disabled by the administrator.' => 'Die E-Mail-Konfiguration wurde vom Administrator deaktiviert.',
    'Close this project' => 'Dieses Projekt schließen',
    'Open this project' => 'Dieses Projekt öffnen',
    'Close a project' => 'Ein Projekt schließen',
    'Do you really want to close this project: "%s"?' => 'Möchten Sie dieses Projekt wirklich schließen: "%s"?',
    'Reopen a project' => 'Ein Projekt wieder öffnen',
    'Do you really want to reopen this project: "%s"?' => 'Möchten Sie dieses Projekt wirklich wieder öffnen: "%s"?',
    'This project is open' => 'Dieses Projekt ist offen',
    'This project is closed' => 'Dieses Projekt ist geschlossen',
    'Unable to upload files, check the permissions of your data folder.' => 'Dateien können nicht hochgeladen werden, überprüfen Sie die Berechtigungen Ihres Datenordners.',
    'Another category with the same name exists in this project' => 'Eine weitere Kategorie mit demselben Namen existiert in diesem Projekt',
    'Comment sent by email successfully.' => 'Kommentar wurde erfolgreich per E-Mail gesendet.',
    'Sent by email to "%s" (%s)' => 'Wurde per E-Mail an [%s] gesendet "%s"',
    'Unable to read uploaded file.' => 'Die hochgeladene Datei konnte nicht gelesen werden.',
    'Database uploaded successfully.' => 'Die Datenbank wurde erfolgreich hochgeladen.',
    'Task sent by email successfully.' => 'Aufgabe wurde erfolgreich per E-Mail gesendet.',
    'There is no category in this project.' => 'Es gibt keine Kategorie in diesem Projekt',
    'Send by email' => 'Per E-Mail senden',
    'Create and send a comment by email' => 'Erstellen und senden Sie einen Kommentar per E-Mail',
    'Subject' => 'Betreff',
    'Upload the database' => 'Datenbank hochladen',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Sie können die zuvor heruntergeladene SQLite-Datenbank (Gzip-Format) hochladen.',
    'Database file' => 'Datenbankdatei',
    'Upload' => 'Hochladen',
    'Your project must have at least one active swimlane.' => 'Ihr Projekt muss mindestens eine aktive Swimlane haben.',
    'Project: %s' => 'Projekt: %s',
    'Automatic action not found: "%s"' => 'Automatische Aktion nicht gefunden: "%s"',
    '%d projects' => '%d Projekte',
    '%d project' => '%d Projekt',
    'There is no project.' => 'Es gibt kein Projekt.',
    'Sort' => 'Sortieren',
    'Project ID' => 'Projekt-ID',
    'Project name' => 'Projekt Name',
    'Public' => 'Öffentlich',
    'Personal' => 'Persönlich',
    '%d tasks' => '%d Aufgaben',
    '%d task' => '%d Aufgabe',
    'Task ID' => 'Aufgaben-ID',
    'Assign automatically a color when due date is expired' => 'Automatisch eine Farbe zuweisen, wenn das Fälligkeitsdatum abgelaufen ist',
    'Total score in this column across all swimlanes' => 'Gesamtpunktzahl in dieser Spalte über alle Swimlanes',
    'HRK - Kuna' => 'HRK - Kroatische Kuna',
    'ARS - Argentine Peso' => 'ARS - Argentinische Peso',
    'COP - Colombian Peso' => 'COP - Kolumbianische Peso',
    '%d groups' => '%d Gruppen',
    '%d group' => '%d Gruppe',
    'Group ID' => 'Gruppen-ID',
    'External ID' => 'Externe ID',
    '%d users' => '%d Benutzer',
    '%d user' => '%d Benutzer',
    'Hide subtasks' => 'Teilaufgaben verstecken',
    'Show subtasks' => 'Teilaufgaben anzeigen',
    'Authentication Parameters' => 'Authentifizierungsparameter',
    'API Access' => 'API-Zugriff',
    'No users found.' => 'Keine Benutzer gefunden.',
    'User ID' => 'Benutzer-ID',
    'Notifications are activated' => 'Benachrichtigungen sind aktiviert',
    'Notifications are disabled' => 'Benachrichtigungen sind deaktiviert',
    'User disabled' => 'Benutzer deaktiviert',
    '%d notifications' => '%d Benachrichtigungen',
    '%d notification' => '%d Benachrichtigung',
    'There is no external integration installed.' => 'Es ist keine externe Integration installiert.',
    'You are not allowed to update tasks assigned to someone else.' => 'Sie sind nicht berechtigt, Aufgaben zu aktualisieren, die jemand anderem zugewiesen wurden.',
    'You are not allowed to change the assignee.' => 'Sie dürfen den Zuständigen nicht ändern.',
    'Task suppression is not permitted' => 'Entfernen von Aufgaben ist nicht erlaubt.',
    'Changing assignee is not permitted' => 'Änderung des Zuständigen ist nicht zulässig',
    'Update only assigned tasks is permitted' => 'Nur zugeordnete Aufgaben dürfen aktualisiert werden',
    'Only for tasks assigned to the current user' => 'Nur für Aufgaben, die dem aktuellen Benutzer zugeordnet sind',
    'My projects' => 'Meine Projekte',
    'You are not a member of any project.' => 'Sie sind nicht Mitglied eines Projektes.',
    'My subtasks' => 'Meine Teilaufgaben',
    '%d subtasks' => '%d Teilaufgaben',
    '%d subtask' => '%d Teilaufgabe',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Das Bewegen einer Aufgabe zwischen diesen Spalten ist nur für Aufgaben zulässig, die dem aktuellen Benutzer zugewiesen sind',
    '[DUPLICATE]' => '[DUPLIKAT]',
    'DKK - Danish Krona' => 'DKK - Dänische Kronen',
    'Remove user from group' => 'Benutzer aus Gruppe löschen',
    'Assign the task to its creator' => 'Aufgabe dem Ersteller zuordnen',
    'This task was sent by email to "%s" with subject "%s".' => 'Diese Aufgabe wurde per Mail an "%s" mit dem Betreff "%s" gesendet.',
    'Predefined Email Subjects' => 'Vordefinierte E-Mail Betreffzeilen',
    'Write one subject by line.' => 'Schreibe ein Betreff pro Zeile.',
    'Create another link' => 'Einen weiteren Link erstellen',
    'BRL - Brazilian Real' => 'BRL - Brasilianische Real',
    'Add a new Kanboard task' => 'Eine neue Kanboard Aufgabe hinzufügen',
    'Subtask not started' => 'Teilaufgabe nicht gestartet',
    'Subtask currently in progress' => 'Teilaufgabe aktuell in Bearbeitung',
    'Subtask completed' => 'Teilaufgabe abgeschlossen',
    'Subtask added successfully.' => 'Teilaufgabe erfolgreich hinzugefügt.',
    '%d subtasks added successfully.' => '%d Teilaufgaben erfolgreich hinzugefügt.',
    'Enter one subtask by line.' => 'Geben Sie eine Teilaufgabe pro Zeile ein.',
    'Predefined Contents' => 'Vordefinierte Inhalte',
    'Predefined contents' => 'Vordefinierte Inhalte',
    'Predefined Task Description' => 'Vordefinierte Aufgabenbeschreibung',
    'Do you really want to remove this template? "%s"' => 'Wollen Sie diese Vorlage wirklich löschen? "%s"',
    'Add predefined task description' => 'Vordefinierte Aufgabenbeschreibung hinzufügen',
    'Predefined Task Descriptions' => 'Vordefinierte Aufgabenbeschreibungen',
    'Template created successfully.' => 'Vorlage erfolgreich erstellt.',
    'Unable to create this template.' => 'Erstellen der Vorlage nicht möglich.',
    'Template updated successfully.' => 'Vorlage erfolgreich geändert.',
    'Unable to update this template.' => 'Aktualisierung der Vorlage nicht möglich.',
    'Template removed successfully.' => 'Vorlage erfolgreich gelöscht.',
    'Unable to remove this template.' => 'Löschen der Vorlage nicht möglich.',
    'Template for the task description' => 'Vorlage für die Aufgabenbeschreibung',
    'The start date is greater than the end date' => 'Das Startdatum ist größer als das Enddatum',
    'Tags must be separated by a comma' => 'Schlagworte müssen per Komma getrennt werden',
    'Only the task title is required' => 'Nur der Aufgaben-Titel wird benötigt',
    'Creator Username' => 'Ersteller Benutzername',
    'Color Name' => 'Farbname',
    'Column Name' => 'Spaltenname',
    'Swimlane Name' => 'Swimlane-Name',
    'Time Estimated' => 'geschätzte Zeit',
    'Time Spent' => 'Zeitaufwand',
    'External Link' => 'externer Link',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Diese Funktion aktiviert den iCal Feed, RSS Feed und die öffentliche Board-Ansicht',
    'Stop the timer of all subtasks when moving a task to another column' => 'Beenden des Timers für alle Unteraufgaben, wenn die Aufgabe in eine andere Spalte verschoben wird',
    'Subtask Title' => 'Titel der Teilaufgabe',
    'Add a subtask and activate the timer when moving a task to another column' => 'Teilaufgabe hinzufügen und den Timer aktivieren, wenn die Aufgabe in eine andere Spalte verschoben wird',
    'days' => 'Tage',
    'minutes' => 'Minuten',
    'seconds' => 'Sekunden',
    'Assign automatically a color when preset start date is reached' => 'Automatisch eine Farbe zuweisen, wenn das Startdatum erreicht ist',
    'Move the task to another column once a predefined start date is reached' => 'Verschieben des Tasks in eine andere Spalte, wenn das definierte Startdatum erreicht ist',
    'This task is now linked to the task %s with the relation "%s"' => 'Diese Aufgabe ist jetzt verknüpft mit der Aufgabe %s mit der Relation "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Die Verknüpfung mit der Relation "%s" zur Aufgabe %s wurde entfernt',
    'Custom Filter:' => 'Benutzerdefinierter Filter:',
    'Unable to find this group.' => 'Diese Gruppe konnte nicht gefunden werden',
    '%s moved the task #%d to the column "%s"' => '%s hat die Aufgabe #%d in die Spalte "%s" verschoben',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s hat die Aufgabe #%d auf die Position %d in der Spalte "%s" verschoben',
    '%s moved the task #%d to the swimlane "%s"' => '%s hat die Aufgabe #%d in die Swimlane "%s" verschoben',
    '%sh spent' => '%sh aufgewendet',
    '%sh estimated' => '%sh angesetzt',
    'Select All' => 'Alle auswählen',
    'Unselect All' => 'Keine auswählen',
    'Apply action' => 'Aktion anwenden',
    'Move selected tasks to another column or swimlane' => 'Ausgewählte Aufgaben in andere Spalte verschieben',
    'Edit tasks in bulk' => 'Massenbearbeitung',
    'Choose the properties that you would like to change for the selected tasks.' => 'Wählen Sie die Eigenschaften aus, die Sie für die ausgewählten Aufgaben ändern möchten.',
    'Configure this project' => 'Projekteinstellungen',
    'Start now' => 'Jetzt starten',
    '%s removed a file from the task #%d' => '%s hat eine Datei aus der Aufgabe #%d entfernt.',
    'Attachment removed from task #%d: %s' => 'Anhang aus Aufgabe #%d entfernt: %s',
    'No color' => 'Keine Farbe',
    'Attachment removed "%s"' => 'Anhang entfernt "%s"',
    '%s removed a file from the task %s' => '%s hat eine Datei aus der Aufgabe entfernt %s',
    'Move the task to another swimlane when assigned to a user' => 'Verschieben der Aufgabe in eine andere Swimlane, wenn sie einem Benutzer zugewiesen wird',
    'Destination swimlane' => 'Ziel Swimlane',
    'Assign a category when the task is moved to a specific swimlane' => 'Kategorie zuweisen, wenn Aufgabe in eine bestimmte Swimlane verschoben wird',
    'Move the task to another swimlane when the category is changed' => 'Verschiebe die Aufgabe in eine andere Swimlane, wenn die Kategorie geändert wird',
    'Reorder this column by priority (ASC)' => 'Spalte nach Priorität ordnen (aufsteigend)',
    'Reorder this column by priority (DESC)' => 'Spalte nach Priorität ordnen (absteigend)',
    'Reorder this column by assignee and priority (ASC)' => 'Spalte nach Zuständigem und Priorität ordnen (aufsteigend)',
    'Reorder this column by assignee and priority (DESC)' => 'Spalte nach Zuständigem und Priorität ordnen (absteigend)',
    'Reorder this column by assignee (A-Z)' => 'Spalte nach Zuständigem ordnen (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Spalte nach Zuständigem ordnen (Z-A)',
    'Reorder this column by due date (ASC)' => 'Spalte nach Fälligkeitsdatum ordnen (aufsteigend)',
    'Reorder this column by due date (DESC)' => 'Spalte nach Fälligkeitsdatum ordnen (absteigend)',
    'Reorder this column by id (ASC)' => 'Diese Spalte nach ID aufsteigend sortieren',
    'Reorder this column by id (DESC)' => 'Diese Spalte nach ID absteigend sortieren',
    '%s moved the task #%d "%s" to the project "%s"' => '%s hat die Aufgabe #%d "%s" in das Projekt "%s" verschoben',
    'Task #%d "%s" has been moved to the project "%s"' => 'Aufgabe #%d "%s" wurde in das Projekt "%s" verschoben',
    'Move the task to another column when the due date is less than a certain number of days' => 'Verschieben der Aufgabe in eine andere Spalte, wenn die Fälligkeit kleiner als eine bestimmte Anzahl von Tagen ist',
    'Automatically update the start date when the task is moved away from a specific column' => 'Aktualisiert automatisch das Startdatum, wenn die Aufgabe aus einer bestimmten Spalte genommen wird',
    'HTTP Client:' => 'HTTP-Client:',
    'Assigned' => 'Zugeordnet',
    'Task limits apply to each swimlane individually' => 'Aufgabenlimit gilt pro Swimlane',
    'Column task limits apply to each swimlane individually' => 'Spaltenaufgabenlimit für jede Swimlane einzeln anwenden',
    'Column task limits are applied to each swimlane individually' => 'Spaltenaufgabenlimit wird für jede Swimlane einzeln angewendet',
    'Column task limits are applied across swimlanes' => 'Spaltenaufgabenlimit wird swimlaneübergreifend angewendet',
    'Task limit: ' => 'Aufgabenlimit',
    'Change to global tag' => 'Zu globalem Schlagwort machen',
    'Do you really want to make the tag "%s" global?' => 'Das Schlagwort "%s" wirklich global machen?',
    'Enable global tags for this project' => 'Globale Schlagworte für dieses Projekt aktivieren',
    'Group membership(s):' => 'Gruppen-Mitgliedschaft(en):',
    '%s is a member of the following group(s): %s' => '%s ist Mitglied in der/den folgenden Gruppe(n): %s',
    '%d/%d group(s) shown' => '%d/%d Gruppe(n) angezeigt',
    'Subtask creation or modification' => 'Teilaufgabe erstellen oder ändern',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Aufgabe einem bestimmten Nutzer zuordnen, wenn die Aufgabe in eine bestimmte Swimlane verschoben wird',
    'Comment' => 'Kommentar',
    'Collapse vertically' => 'Vertikal zuklappen',
    'Expand vertically' => 'Vertikal erweitern',
    'MXN - Mexican Peso' => 'MXN - Mexikanischer Peso',
    'Estimated vs actual time per column' => 'Geschätzte vs. tatsächliche Zeit pro Spalte',
    'HUF - Hungarian Forint' => 'HUF - Ungarischer Forint',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Sie müssen eine Datei auswählen, um sie als Ihr Avatar hochzuladen!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Die hochgeladene Datei ist kein gültiges Bild! (Nur *.gif, *.jpg, *.jpeg und *.png sind erlaubt!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Fälligkeitsdatum automatisch setzen, wenn die Aufgabe aus einer bestimmten Spalte verschoben wird',
    'No other projects found.' => 'Keine weiteren Projekte gefunden.',
    'Tasks copied successfully.' => 'Aufgaben erfolgreich kopiert.',
    'Unable to copy tasks.' => 'Aufgaben können nicht kopiert werden.',
    'Theme' => 'Thema',
    'Theme:' => 'Thema:',
    'Light theme' => 'Helles Thema',
    'Dark theme' => 'Dunkles Thema',
    'Automatic theme - Sync with system' => 'Automatisches Thema - Mit System synchronisieren',
    'Application managers or more' => 'Anwendungsmanager oder mehr',
    'Administrators' => 'Administratoren',
    'Visibility:' => 'Sichtbarkeit:',
    'Standard users' => 'Standardbenutzer',
    'Visibility is required' => 'Sichtbarkeit ist erforderlich',
    'The visibility should be an app role' => 'Die Sichtbarkeit sollte eine App-Rolle sein',
    'Reply' => 'Antworten',
    '%s wrote: ' => '%s schrieb: ',
    'Number of visible tasks in this column and swimlane' => 'Anzahl sichtbarer Aufgaben in dieser Spalte und Swimlane',
    'Number of tasks in this swimlane' => 'Anzahl der Aufgaben in dieser Swimlane',
    'Unable to find another subtask in progress, you can close this window.' => 'Es konnte keine weitere Teilaufgabe in Bearbeitung gefunden werden, Sie können dieses Fenster schließen.',
    'This theme is invalid' => 'Dieses Thema ist ungültig',
    'This role is invalid' => 'Diese Rolle ist ungültig',
    'This timezone is invalid' => 'Diese Zeitzone ist ungültig',
    'This language is invalid' => 'Diese Sprache ist ungültig',
    'This URL is invalid' => 'Diese URL ist ungültig',
    'Date format invalid' => 'Ungültiges Datumsformat',
    'Time format invalid' => 'Ungültiges Zeitformat',
    'Invalid Mail transport' => 'Ungültiger Mail-Transport',
    'Color invalid' => 'Ungültige Farbe',
    'This value must be greater or equal to %d' => 'Dieser Wert muss größer oder gleich %d sein',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Fügen Sie am Anfang der Datei ein BOM hinzu (erforderlich für Microsoft Excel)',
    'Just add these tag(s)' => 'Nur diese Tags hinzufügen',
    'Remove internal link(s)' => 'Interne Links entfernen',
    'Import tasks from another project' => 'Aufgaben aus einem anderen Projekt importieren',
    'Select the project to copy tasks from' => 'Wählen Sie das Projekt aus, aus dem Sie Aufgaben kopieren möchten',
    'The total maximum allowed attachments size is %sB.' => 'Die maximal zulässige Gesamtgröße für Anhänge beträgt %sB.',
    'Add attachments' => 'Anhänge hinzufügen',
    'Task #%d "%s" is overdue' => 'Aufgabe #%d "%s" ist überfällig',
    'Enable notifications by default for all new users' => 'Benachrichtigungen standardmäßig für alle neuen Benutzer aktivieren',
];
